︠4f7875ed-a488-46f0-a41e-522e0a7edbe7i︠
%md
# Higher-Order Equation of Motion

Our goal is to solve the equation of motion for the high-order acceleration $f$, a given higher-order Lagrangian $L$.

Related worksheet: <font size=2>[https://cloud.sagemath.com/projects/b04b5777-e269-4c8f-a4b8-b21dbe1c93c6/files/Two%20Equations%20of%20Lagrange.sagews](https://cloud.sagemath.com/projects/b04b5777-e269-4c8f-a4b8-b21dbe1c93c6/files/Two%20Equations%20of%20Lagrange.sagews)</font>

Calculations are done using [SageManifolds](http://sagemanifolds.obspm.fr/).
︡de442fa3-412d-4df2-a32b-9690b098c991︡{"done":true,"md":"# Higher-Order Equation of Motion\n\nOur goal is to solve the equation of motion for the high-order acceleration $f$, a given higher-order Lagrangian $L$.\n\nRelated worksheet: <font size=2>[https://cloud.sagemath.com/projects/b04b5777-e269-4c8f-a4b8-b21dbe1c93c6/files/Two%20Equations%20of%20Lagrange.sagews](https://cloud.sagemath.com/projects/b04b5777-e269-4c8f-a4b8-b21dbe1c93c6/files/Two%20Equations%20of%20Lagrange.sagews)</font>\n\nCalculations are done using [SageManifolds](http://sagemanifolds.obspm.fr/)."}
︠d0370244-d5be-4c50-a35d-2b383b439604s︠
%typeset_mode True
︡b75c72cf-46d6-4df8-ba26-245180612109︡{"done":true}︡
︠58c83ce4-4ce2-48ad-89e9-9506e03b25e2s︠
from sage.manifolds.utilities import exterior_derivative as d
def ev(N): return (lambda x: N.contract(x))
︡c215ce98-6b9f-417b-b7e5-dc81087729ee︡{"done":true}︡
︠d3d2706e-fcb3-4687-962a-6a15c526d84ei︠
%md
Variables
︡c48bd37c-31f8-4482-be0e-147237bb1c24︡{"done":true,"md":"Variables"}
︠44c7c909-ae46-493d-a2e0-e7290d258352s︠
M = Manifold(5,'M')
coord.<t, x, v, a, s> = M.chart()
︡037e5308-9370-4770-bcfc-45f42bb09593︡{"done":true}︡
︠5982b416-d038-4e03-8657-caa90934c529i︠
%md
Vectors (partial derivatives)
︡d65f9a94-de16-4a5c-b05b-3c98dce73e22︡{"done":true,"md":"Vectors (partial derivatives)"}
︠67a38062-ffc8-4b73-898e-5332d23da74cs︠
[Dt,Dx,Dv,Da,Ds] = coord.frame()
︡91cf7c1a-8d42-4724-9647-ca3b8f93dce0︡{"done":true}︡
︠c2f58eb8-7fdd-42f7-9e4d-f409c01c2037i︠
%md
Forms
︡8f1c36b8-4fa3-4a11-b0c7-f74ead823104︡{"done":true,"md":"Forms"}
︠7bbd9429-818f-4040-9d38-09435b05749fs︠
[dt,dx,dv,da,ds] = coord.coframe()
︡10c86d9b-f306-447e-9591-3f11c1b9fbe0︡{"done":true}︡
︠4aa9a68c-1655-46c7-a2c5-fb818e692930i︠
%md
## General Lagrangian ##
︡9a49a77c-57d5-4143-908d-740935b1bcfc︡{"done":true,"md":"## General Lagrangian ##"}
︠c3341358-ea6e-40dc-9d76-7c68739e1a68s︠
L = M.scalar_field(function('L')(*list(coord))); L.display()
︡40eeca12-c0b9-48a5-9fc9-a6e339f50506︡{"html":"<div align='center'>$\\displaystyle \\begin{array}{llcl} &amp; M &amp; \\longrightarrow &amp; \\mathbb{R} \\\\ &amp; \\left(t, x, v, a, s\\right) &amp; \\longmapsto &amp; L\\left(t, x, v, a, s\\right) \\end{array}$</div>"}︡{"done":true}︡
︠07b1020b-cc9b-49e8-9503-5e79b4ccadd2i︠
%md
## Kinematics

$f$ is an unknown function that is the analogue of acceleration for a higher-order equation of motion.
︡4e8970d1-ddce-4106-a243-5c6666a2e3b9︡{"done":true,"md":"## Kinematics\n\n$f$ is an unknown function that is the analogue of acceleration for a higher-order equation of motion."}
︠abae1282-0a9e-4701-ac9f-2c068b96a3bas︠
f = M.scalar_field(function('f')(*list(coord))); f.display()
︡705b4a3a-7b58-4b05-a657-1ee517df73e6︡{"html":"<div align='center'>$\\displaystyle \\begin{array}{llcl} &amp; M &amp; \\longrightarrow &amp; \\mathbb{R} \\\\ &amp; \\left(t, x, v, a, s\\right) &amp; \\longmapsto &amp; f\\left(t, x, v, a, s\\right) \\end{array}$</div>"}︡{"done":true}︡
︠e9282ebb-0219-409e-b812-dd9eeb7146ccs︠
N = Dt + v*Dx + a*Dv + s*Da + f*Ds; N.display()
︡071fd79b-80a9-4db8-9a27-ac75b838abda︡{"html":"<div align='center'>$\\displaystyle \\frac{\\partial}{\\partial t } + v \\frac{\\partial}{\\partial x } + a \\frac{\\partial}{\\partial v } + s \\frac{\\partial}{\\partial a } + f\\left(t, x, v, a, s\\right) \\frac{\\partial}{\\partial s }$</div>"}︡{"done":true}︡
︠5af559b0-86ac-4bc1-beb5-13b02684d70di︠
%md
The Equation of Lagrange can be defined with the aid of the following auxillary fields
︡8baa103b-638b-4ba3-9218-3bc89e39b245︡{"done":true,"md":"The Equation of Lagrange can be defined with the aid of the following auxillary fields"}
︠d5724ce7-14c8-4a7e-bf08-4eb0d2b09d75s︠
r=Ds(L); r.display()
︡cf619060-2fff-4a8a-9929-1c8bd8b75498︡{"html":"<div align='center'>$\\displaystyle \\begin{array}{llcl} &amp; M &amp; \\longrightarrow &amp; \\mathbb{R} \\\\ &amp; \\left(t, x, v, a, s\\right) &amp; \\longmapsto &amp; \\frac{\\partial\\,L}{\\partial s} \\end{array}$</div>"}︡{"done":true}︡
︠022c96a7-87d9-4b75-aa67-147d4e13d708s︠
q=Da(L)-N(r); q.display()
︡976d410d-56f0-401e-b2db-a9c075f8167e︡{"html":"<div align='center'>$\\displaystyle \\begin{array}{llcl} &amp; M &amp; \\longrightarrow &amp; \\mathbb{R} \\\\ &amp; \\left(t, x, v, a, s\\right) &amp; \\longmapsto &amp; -v \\frac{\\partial^2\\,L}{\\partial x\\partial s} - a \\frac{\\partial^2\\,L}{\\partial v\\partial s} - s \\frac{\\partial^2\\,L}{\\partial a\\partial s} - f\\left(t, x, v, a, s\\right) \\frac{\\partial^2\\,L}{\\partial s ^ 2} - \\frac{\\partial^2\\,L}{\\partial t\\partial s} + \\frac{\\partial\\,L}{\\partial a} \\end{array}$</div>"}︡{"done":true}︡
︠b26b8d3b-443f-4a67-a4fe-25b42d7aeb1fs︠
p=Dv(L)-N(q); p.display()
︡f42ca86f-309b-4613-89e2-56e14bf56e29︡{"html":"<div align='center'>$\\displaystyle \\begin{array}{llcl} &amp; M &amp; \\longrightarrow &amp; \\mathbb{R} \\\\ &amp; \\left(t, x, v, a, s\\right) &amp; \\longmapsto &amp; v^{2} \\frac{\\partial^3\\,L}{\\partial x ^ 2\\partial s} + a^{2} \\frac{\\partial^3\\,L}{\\partial v ^ 2\\partial s} + 2 \\, a s \\frac{\\partial^3\\,L}{\\partial v\\partial a\\partial s} + 2 \\, a f\\left(t, x, v, a, s\\right) \\frac{\\partial^3\\,L}{\\partial v\\partial s ^ 2} + s^{2} \\frac{\\partial^3\\,L}{\\partial a ^ 2\\partial s} + 2 \\, s f\\left(t, x, v, a, s\\right) \\frac{\\partial^3\\,L}{\\partial a\\partial s ^ 2} + f\\left(t, x, v, a, s\\right)^{2} \\frac{\\partial^3\\,L}{\\partial s ^ 3} + {\\left(2 \\, a \\frac{\\partial^3\\,L}{\\partial x\\partial v\\partial s} + 2 \\, s \\frac{\\partial^3\\,L}{\\partial x\\partial a\\partial s} + 2 \\, f\\left(t, x, v, a, s\\right) \\frac{\\partial^3\\,L}{\\partial x\\partial s ^ 2} + \\frac{\\partial^2\\,L}{\\partial s ^ 2} \\frac{\\partial\\,f}{\\partial x} + 2 \\, \\frac{\\partial^3\\,L}{\\partial t\\partial x\\partial s} - \\frac{\\partial^2\\,L}{\\partial x\\partial a}\\right)} v + 2 \\, a \\frac{\\partial^3\\,L}{\\partial t\\partial v\\partial s} + 2 \\, s \\frac{\\partial^3\\,L}{\\partial t\\partial a\\partial s} + 2 \\, f\\left(t, x, v, a, s\\right) \\frac{\\partial^3\\,L}{\\partial t\\partial s ^ 2} + a \\frac{\\partial^2\\,L}{\\partial x\\partial s} - a \\frac{\\partial^2\\,L}{\\partial v\\partial a} + s \\frac{\\partial^2\\,L}{\\partial v\\partial s} - s \\frac{\\partial^2\\,L}{\\partial a ^ 2} + {\\left(a \\frac{\\partial\\,f}{\\partial v} + s \\frac{\\partial\\,f}{\\partial a} + f\\left(t, x, v, a, s\\right) \\frac{\\partial\\,f}{\\partial s} + \\frac{\\partial\\,f}{\\partial t}\\right)} \\frac{\\partial^2\\,L}{\\partial s ^ 2} + \\frac{\\partial^3\\,L}{\\partial t ^ 2\\partial s} - \\frac{\\partial^2\\,L}{\\partial t\\partial a} + \\frac{\\partial\\,L}{\\partial v} \\end{array}$</div>"}︡{"done":true}︡
︠abc7aca5-5761-4fbc-8a9c-6dd203b65176s︠
eq1 = (N(p)-Dx(L)); eq1.display()
︡7126c472-49ab-41fb-ba19-61c056d7433b︡{"html":"<div align='center'>$\\displaystyle \\begin{array}{llcl} &amp; M &amp; \\longrightarrow &amp; \\mathbb{R} \\\\ &amp; \\left(t, x, v, a, s\\right) &amp; \\longmapsto &amp; v^{3} \\frac{\\partial^4\\,L}{\\partial x ^ 3\\partial s} + a^{3} \\frac{\\partial^4\\,L}{\\partial v ^ 3\\partial s} + 3 \\, a^{2} s \\frac{\\partial^4\\,L}{\\partial v ^ 2\\partial a\\partial s} + 3 \\, a^{2} f\\left(t, x, v, a, s\\right) \\frac{\\partial^4\\,L}{\\partial v ^ 2\\partial s ^ 2} + 3 \\, a s^{2} \\frac{\\partial^4\\,L}{\\partial v\\partial a ^ 2\\partial s} + 6 \\, a s f\\left(t, x, v, a, s\\right) \\frac{\\partial^4\\,L}{\\partial v\\partial a\\partial s ^ 2} + 3 \\, a f\\left(t, x, v, a, s\\right)^{2} \\frac{\\partial^4\\,L}{\\partial v\\partial s ^ 3} + s^{3} \\frac{\\partial^4\\,L}{\\partial a ^ 3\\partial s} + 3 \\, s^{2} f\\left(t, x, v, a, s\\right) \\frac{\\partial^4\\,L}{\\partial a ^ 2\\partial s ^ 2} + 3 \\, s f\\left(t, x, v, a, s\\right)^{2} \\frac{\\partial^4\\,L}{\\partial a\\partial s ^ 3} + f\\left(t, x, v, a, s\\right)^{3} \\frac{\\partial^4\\,L}{\\partial s ^ 4} + {\\left(3 \\, a \\frac{\\partial^4\\,L}{\\partial x ^ 2\\partial v\\partial s} + 3 \\, s \\frac{\\partial^4\\,L}{\\partial x ^ 2\\partial a\\partial s} + 3 \\, f\\left(t, x, v, a, s\\right) \\frac{\\partial^4\\,L}{\\partial x ^ 2\\partial s ^ 2} + 3 \\, \\frac{\\partial^3\\,L}{\\partial x\\partial s ^ 2} \\frac{\\partial\\,f}{\\partial x} + \\frac{\\partial^2\\,L}{\\partial s ^ 2} \\frac{\\partial^2\\,f}{\\partial x ^ 2} + 3 \\, \\frac{\\partial^4\\,L}{\\partial t\\partial x ^ 2\\partial s} - \\frac{\\partial^3\\,L}{\\partial x ^ 2\\partial a}\\right)} v^{2} + 3 \\, a^{2} \\frac{\\partial^4\\,L}{\\partial t\\partial v ^ 2\\partial s} + 6 \\, a s \\frac{\\partial^4\\,L}{\\partial t\\partial v\\partial a\\partial s} + 6 \\, a f\\left(t, x, v, a, s\\right) \\frac{\\partial^4\\,L}{\\partial t\\partial v\\partial s ^ 2} + 3 \\, s^{2} \\frac{\\partial^4\\,L}{\\partial t\\partial a ^ 2\\partial s} + 6 \\, s f\\left(t, x, v, a, s\\right) \\frac{\\partial^4\\,L}{\\partial t\\partial a\\partial s ^ 2} + 3 \\, f\\left(t, x, v, a, s\\right)^{2} \\frac{\\partial^4\\,L}{\\partial t\\partial s ^ 3} + 3 \\, a^{2} \\frac{\\partial^3\\,L}{\\partial x\\partial v\\partial s} + 3 \\, a s \\frac{\\partial^3\\,L}{\\partial x\\partial a\\partial s} + 3 \\, a f\\left(t, x, v, a, s\\right) \\frac{\\partial^3\\,L}{\\partial x\\partial s ^ 2} - a^{2} \\frac{\\partial^3\\,L}{\\partial v ^ 2\\partial a} + 3 \\, a s \\frac{\\partial^3\\,L}{\\partial v ^ 2\\partial s} - 2 \\, a s \\frac{\\partial^3\\,L}{\\partial v\\partial a ^ 2} - s^{2} \\frac{\\partial^3\\,L}{\\partial a ^ 3} + s f\\left(t, x, v, a, s\\right) \\frac{\\partial^3\\,L}{\\partial a ^ 2\\partial s} + {\\left(3 \\, a^{2} \\frac{\\partial^4\\,L}{\\partial x\\partial v ^ 2\\partial s} + 6 \\, a s \\frac{\\partial^4\\,L}{\\partial x\\partial v\\partial a\\partial s} + 6 \\, a f\\left(t, x, v, a, s\\right) \\frac{\\partial^4\\,L}{\\partial x\\partial v\\partial s ^ 2} + 3 \\, s^{2} \\frac{\\partial^4\\,L}{\\partial x\\partial a ^ 2\\partial s} + 6 \\, s f\\left(t, x, v, a, s\\right) \\frac{\\partial^4\\,L}{\\partial x\\partial a\\partial s ^ 2} + 3 \\, f\\left(t, x, v, a, s\\right)^{2} \\frac{\\partial^4\\,L}{\\partial x\\partial s ^ 3} + 3 \\, a \\frac{\\partial^3\\,L}{\\partial v\\partial s ^ 2} \\frac{\\partial\\,f}{\\partial x} + 3 \\, s \\frac{\\partial^3\\,L}{\\partial a\\partial s ^ 2} \\frac{\\partial\\,f}{\\partial x} + 3 \\, f\\left(t, x, v, a, s\\right) \\frac{\\partial^3\\,L}{\\partial s ^ 3} \\frac{\\partial\\,f}{\\partial x} + 6 \\, a \\frac{\\partial^4\\,L}{\\partial t\\partial x\\partial v\\partial s} + 6 \\, s \\frac{\\partial^4\\,L}{\\partial t\\partial x\\partial a\\partial s} + 6 \\, f\\left(t, x, v, a, s\\right) \\frac{\\partial^4\\,L}{\\partial t\\partial x\\partial s ^ 2} + 3 \\, a \\frac{\\partial^3\\,L}{\\partial x ^ 2\\partial s} - 2 \\, a \\frac{\\partial^3\\,L}{\\partial x\\partial v\\partial a} + 3 \\, s \\frac{\\partial^3\\,L}{\\partial x\\partial v\\partial s} - 2 \\, s \\frac{\\partial^3\\,L}{\\partial x\\partial a ^ 2} + f\\left(t, x, v, a, s\\right) \\frac{\\partial^3\\,L}{\\partial x\\partial a\\partial s} + 3 \\, {\\left(a \\frac{\\partial\\,f}{\\partial v} + s \\frac{\\partial\\,f}{\\partial a} + f\\left(t, x, v, a, s\\right) \\frac{\\partial\\,f}{\\partial s} + \\frac{\\partial\\,f}{\\partial t}\\right)} \\frac{\\partial^3\\,L}{\\partial x\\partial s ^ 2} + {\\left(2 \\, a \\frac{\\partial^2\\,f}{\\partial x\\partial v} + 2 \\, s \\frac{\\partial^2\\,f}{\\partial x\\partial a} + 2 \\, f\\left(t, x, v, a, s\\right) \\frac{\\partial^2\\,f}{\\partial x\\partial s} + \\frac{\\partial\\,f}{\\partial x} \\frac{\\partial\\,f}{\\partial s} + 2 \\, \\frac{\\partial^2\\,f}{\\partial t\\partial x}\\right)} \\frac{\\partial^2\\,L}{\\partial s ^ 2} + 3 \\, \\frac{\\partial^3\\,L}{\\partial t\\partial s ^ 2} \\frac{\\partial\\,f}{\\partial x} + 3 \\, \\frac{\\partial^4\\,L}{\\partial t ^ 2\\partial x\\partial s} - 2 \\, \\frac{\\partial^3\\,L}{\\partial t\\partial x\\partial a} + \\frac{\\partial^2\\,L}{\\partial x\\partial v}\\right)} v + 3 \\, a \\frac{\\partial^4\\,L}{\\partial t ^ 2\\partial v\\partial s} + 3 \\, s \\frac{\\partial^4\\,L}{\\partial t ^ 2\\partial a\\partial s} + 3 \\, f\\left(t, x, v, a, s\\right) \\frac{\\partial^4\\,L}{\\partial t ^ 2\\partial s ^ 2} + 3 \\, a \\frac{\\partial^3\\,L}{\\partial t\\partial x\\partial s} - 2 \\, a \\frac{\\partial^3\\,L}{\\partial t\\partial v\\partial a} + 3 \\, s \\frac{\\partial^3\\,L}{\\partial t\\partial v\\partial s} - 2 \\, s \\frac{\\partial^3\\,L}{\\partial t\\partial a ^ 2} + f\\left(t, x, v, a, s\\right) \\frac{\\partial^3\\,L}{\\partial t\\partial a\\partial s} + 3 \\, {\\left(a \\frac{\\partial\\,f}{\\partial v} + s \\frac{\\partial\\,f}{\\partial a} + f\\left(t, x, v, a, s\\right) \\frac{\\partial\\,f}{\\partial s} + \\frac{\\partial\\,f}{\\partial t}\\right)} \\frac{\\partial^3\\,L}{\\partial t\\partial s ^ 2} - a \\frac{\\partial^2\\,L}{\\partial x\\partial a} + s \\frac{\\partial^2\\,L}{\\partial x\\partial s} + a \\frac{\\partial^2\\,L}{\\partial v ^ 2} + {\\left(3 \\, s^{2} + a f\\left(t, x, v, a, s\\right)\\right)} \\frac{\\partial^3\\,L}{\\partial v\\partial a\\partial s} + 2 \\, f\\left(t, x, v, a, s\\right) \\frac{\\partial^2\\,L}{\\partial v\\partial s} + 3 \\, {\\left(a^{2} \\frac{\\partial\\,f}{\\partial v} + a s \\frac{\\partial\\,f}{\\partial a} + a f\\left(t, x, v, a, s\\right) \\frac{\\partial\\,f}{\\partial s} + s f\\left(t, x, v, a, s\\right) + a \\frac{\\partial\\,f}{\\partial t}\\right)} \\frac{\\partial^3\\,L}{\\partial v\\partial s ^ 2} - f\\left(t, x, v, a, s\\right) \\frac{\\partial^2\\,L}{\\partial a ^ 2} + {\\left(3 \\, a s \\frac{\\partial\\,f}{\\partial v} + 3 \\, s^{2} \\frac{\\partial\\,f}{\\partial a} + 3 \\, s f\\left(t, x, v, a, s\\right) \\frac{\\partial\\,f}{\\partial s} + 2 \\, f\\left(t, x, v, a, s\\right)^{2} + 3 \\, s \\frac{\\partial\\,f}{\\partial t}\\right)} \\frac{\\partial^3\\,L}{\\partial a\\partial s ^ 2} + {\\left(a^{2} \\frac{\\partial^2\\,f}{\\partial v ^ 2} + 2 \\, a s \\frac{\\partial^2\\,f}{\\partial v\\partial a} + 2 \\, a f\\left(t, x, v, a, s\\right) \\frac{\\partial^2\\,f}{\\partial v\\partial s} + s^{2} \\frac{\\partial^2\\,f}{\\partial a ^ 2} + 2 \\, s f\\left(t, x, v, a, s\\right) \\frac{\\partial^2\\,f}{\\partial a\\partial s} + s \\frac{\\partial\\,f}{\\partial a} \\frac{\\partial\\,f}{\\partial s} + f\\left(t, x, v, a, s\\right) \\frac{\\partial\\,f}{\\partial s}^{2} + f\\left(t, x, v, a, s\\right)^{2} \\frac{\\partial^2\\,f}{\\partial s ^ 2} + 2 \\, a \\frac{\\partial^2\\,f}{\\partial t\\partial v} + 2 \\, s \\frac{\\partial^2\\,f}{\\partial t\\partial a} + 2 \\, f\\left(t, x, v, a, s\\right) \\frac{\\partial^2\\,f}{\\partial t\\partial s} + a \\frac{\\partial\\,f}{\\partial x} + {\\left(a \\frac{\\partial\\,f}{\\partial s} + s\\right)} \\frac{\\partial\\,f}{\\partial v} + f\\left(t, x, v, a, s\\right) \\frac{\\partial\\,f}{\\partial a} + \\frac{\\partial\\,f}{\\partial t} \\frac{\\partial\\,f}{\\partial s} + \\frac{\\partial^2\\,f}{\\partial t ^ 2}\\right)} \\frac{\\partial^2\\,L}{\\partial s ^ 2} + 3 \\, {\\left(a f\\left(t, x, v, a, s\\right) \\frac{\\partial\\,f}{\\partial v} + s f\\left(t, x, v, a, s\\right) \\frac{\\partial\\,f}{\\partial a} + f\\left(t, x, v, a, s\\right)^{2} \\frac{\\partial\\,f}{\\partial s} + f\\left(t, x, v, a, s\\right) \\frac{\\partial\\,f}{\\partial t}\\right)} \\frac{\\partial^3\\,L}{\\partial s ^ 3} + \\frac{\\partial^4\\,L}{\\partial t ^ 3\\partial s} - \\frac{\\partial^3\\,L}{\\partial t ^ 2\\partial a} + \\frac{\\partial^2\\,L}{\\partial t\\partial v} - \\frac{\\partial\\,L}{\\partial x} \\end{array}$</div>"}︡{"done":true}︡
︠a17d1662-f8d1-437c-83c3-eb9876cf196fi︠
%md
Number of terms in this expression:
︡4831b008-9b84-46c4-b96a-90844cbebdfb︡{"done":true,"md":"Number of terms in this expression:"}
︠c6b9c6c4-9ccb-4caa-99a5-5cf6917aaf2fs︠
len(eq1.expr().expand())
︡3356ce17-947d-4403-839e-25c1c62817be︡{"html":"<div align='center'>$\\displaystyle 116$</div>"}︡{"done":true}︡
︠b9af10d3-b4aa-4251-a680-552dbeff9b40i︠
%md
We want to solve this equation (eq1 = 0) for $f$ in terms of $L$.

The equation can also be written in the following form:
︡2f33216c-dfc1-4c66-a6fa-12a10a378f0b︡{"done":true,"md":"We want to solve this equation (eq1 = 0) for $f$ in terms of $L$.\n\nThe equation can also be written in the following form:"}
︠8eeac1b5-1c8c-4976-8430-906d945a5335s︠
eq2 = N(Dv(L)) - N(N(Da(L))) + N(N(N(Ds(L)))) - Dx(L)
︡3c94ff06-c5c5-4620-a2ba-64e12a73e276︡{"done":true}{"done":true}︡
︠4772211a-2cc3-4f4f-898c-2029fee4b457s︠
N.display()
︡b160dc7e-bea6-4da6-b1f7-e433ebb2f41a︡{"html":"<div align='center'>$\\displaystyle \\frac{\\partial}{\\partial t } + v \\frac{\\partial}{\\partial x } + a \\frac{\\partial}{\\partial v } + s \\frac{\\partial}{\\partial a } + f\\left(t, x, v, a, s\\right) \\frac{\\partial}{\\partial s }$</div>"}︡{"done":true}︡
︠c7c51ec3-2086-4e57-8dc2-e2f390c033fas︠
eq1 == eq2
︡bc7f6e5c-8f0c-4d84-99b7-9702f3c3e160︡{"html":"<div align='center'>$\\displaystyle \\mathrm{True}$</div>"}︡{"done":true}
︠cd8e453d-10b9-4ce4-9ccb-216db197bf29i︠
%md
But we would prefer to write it as a polynomial in $N(N(f))$, $N(f)$, and powers of $f$. If we write $f$ instead of $N(Ds(L))$, $N(Da(L))$ and $N(Dv(L))$ above then we get new coefficients and terms in powers of $f$.
︡905b2f26-1fa2-4b27-9372-283c3226c98e︡{"done":true,"md":"But we would prefer to write it as a polynomial in $N(N(f))$, $N(f)$, and powers of $f$. If we write $f$ instead of $N(Ds(L))$, $N(Da(L))$ and $N(Dv(L))$ above then we get new coefficients and terms in powers of $f$."}
︠73c9bfa2-37b1-42e1-a7cc-cce1c22ab06c︠
N(N(f)).display()
︡d95328b4-e6ad-478b-aeaf-321301b8ebc5︡{"html":"<div align='center'>$\\displaystyle \\begin{array}{llcl} &amp; M &amp; \\longrightarrow &amp; \\mathbb{R} \\\\ &amp; \\left(t, x, v, a, s\\right) &amp; \\longmapsto &amp; v^{2} \\frac{\\partial^2\\,f}{\\partial x ^ 2} + a^{2} \\frac{\\partial^2\\,f}{\\partial v ^ 2} + 2 \\, a s \\frac{\\partial^2\\,f}{\\partial v\\partial a} + 2 \\, a f\\left(t, x, v, a, s\\right) \\frac{\\partial^2\\,f}{\\partial v\\partial s} + s^{2} \\frac{\\partial^2\\,f}{\\partial a ^ 2} + 2 \\, s f\\left(t, x, v, a, s\\right) \\frac{\\partial^2\\,f}{\\partial a\\partial s} + s \\frac{\\partial\\,f}{\\partial a} \\frac{\\partial\\,f}{\\partial s} + f\\left(t, x, v, a, s\\right) \\frac{\\partial\\,f}{\\partial s}^{2} + f\\left(t, x, v, a, s\\right)^{2} \\frac{\\partial^2\\,f}{\\partial s ^ 2} + {\\left(2 \\, a \\frac{\\partial^2\\,f}{\\partial x\\partial v} + 2 \\, s \\frac{\\partial^2\\,f}{\\partial x\\partial a} + 2 \\, f\\left(t, x, v, a, s\\right) \\frac{\\partial^2\\,f}{\\partial x\\partial s} + \\frac{\\partial\\,f}{\\partial x} \\frac{\\partial\\,f}{\\partial s} + 2 \\, \\frac{\\partial^2\\,f}{\\partial t\\partial x}\\right)} v + 2 \\, a \\frac{\\partial^2\\,f}{\\partial t\\partial v} + 2 \\, s \\frac{\\partial^2\\,f}{\\partial t\\partial a} + 2 \\, f\\left(t, x, v, a, s\\right) \\frac{\\partial^2\\,f}{\\partial t\\partial s} + a \\frac{\\partial\\,f}{\\partial x} + {\\left(a \\frac{\\partial\\,f}{\\partial s} + s\\right)} \\frac{\\partial\\,f}{\\partial v} + f\\left(t, x, v, a, s\\right) \\frac{\\partial\\,f}{\\partial a} + \\frac{\\partial\\,f}{\\partial t} \\frac{\\partial\\,f}{\\partial s} + \\frac{\\partial^2\\,f}{\\partial t ^ 2} \\end{array}$</div>"}︡{"done":true}︡
︠a674d180-0204-4cc9-a694-b7f17b7f7179i︠
%md
Terms 2$^\textit{nd}$ order in $f$ arise from the Liebniz rule applied to the differential operator $N^2$ on the term $Ds\ f$ in $N(Ds(L))$. For example
︡9162bfcc-ed26-4014-9b26-95677e82f1fe︡{"done":true,"md":"Terms 2$^\\textit{nd}$ order in $f$ arise from the Liebniz rule applied to the differential operator $N^2$ on the term $Ds\\ f$ in $N(Ds(L))$. For example"}
︠b3125f13-9223-4f9a-b4e5-dbab8af5b8cd︠
t2 = eq1.expr().coefficient(diff(f.expr(),t,t))*diff(f.expr(),t,t); M.scalar_field(t2).display()
︡0cf2e1d7-a7cf-429c-b32d-ea9f51772121︡{"html":"<div align='center'>$\\displaystyle \\begin{array}{llcl} &amp; M &amp; \\longrightarrow &amp; \\mathbb{R} \\\\ &amp; \\left(t, x, v, a, s\\right) &amp; \\longmapsto &amp; \\frac{\\partial^2\\,L}{\\partial s ^ 2} \\frac{\\partial^2\\,f}{\\partial t ^ 2} \\end{array}$</div>"}︡{"done":true}
︠b3771869-bba0-4af7-9f33-38f2f5754a04i︠
%md
The necessary coefficient can be read from the above.
︡cce90b80-5452-449b-b119-eb996d406cbd︡{"done":true,"md":"The necessary coefficient can be read from the above."}
︠c70cedd1-86ab-499c-bb8f-6d03c01a65f5︠
c2 = (Ds(Ds(L))*N(N(f))); c2.display()
︡6218410a-49d7-4e53-8fbf-2946c8da331f︡{"html":"<div align='center'>$\\displaystyle \\begin{array}{llcl} &amp; M &amp; \\longrightarrow &amp; \\mathbb{R} \\\\ &amp; \\left(t, x, v, a, s\\right) &amp; \\longmapsto &amp; v^{2} \\frac{\\partial^2\\,L}{\\partial s ^ 2} \\frac{\\partial^2\\,f}{\\partial x ^ 2} + {\\left(2 \\, a \\frac{\\partial^2\\,f}{\\partial x\\partial v} + 2 \\, s \\frac{\\partial^2\\,f}{\\partial x\\partial a} + 2 \\, f\\left(t, x, v, a, s\\right) \\frac{\\partial^2\\,f}{\\partial x\\partial s} + \\frac{\\partial\\,f}{\\partial x} \\frac{\\partial\\,f}{\\partial s} + 2 \\, \\frac{\\partial^2\\,f}{\\partial t\\partial x}\\right)} v \\frac{\\partial^2\\,L}{\\partial s ^ 2} + {\\left(a^{2} \\frac{\\partial^2\\,f}{\\partial v ^ 2} + 2 \\, a s \\frac{\\partial^2\\,f}{\\partial v\\partial a} + 2 \\, a f\\left(t, x, v, a, s\\right) \\frac{\\partial^2\\,f}{\\partial v\\partial s} + s^{2} \\frac{\\partial^2\\,f}{\\partial a ^ 2} + 2 \\, s f\\left(t, x, v, a, s\\right) \\frac{\\partial^2\\,f}{\\partial a\\partial s} + s \\frac{\\partial\\,f}{\\partial a} \\frac{\\partial\\,f}{\\partial s} + f\\left(t, x, v, a, s\\right) \\frac{\\partial\\,f}{\\partial s}^{2} + f\\left(t, x, v, a, s\\right)^{2} \\frac{\\partial^2\\,f}{\\partial s ^ 2} + 2 \\, a \\frac{\\partial^2\\,f}{\\partial t\\partial v} + 2 \\, s \\frac{\\partial^2\\,f}{\\partial t\\partial a} + 2 \\, f\\left(t, x, v, a, s\\right) \\frac{\\partial^2\\,f}{\\partial t\\partial s} + a \\frac{\\partial\\,f}{\\partial x} + {\\left(a \\frac{\\partial\\,f}{\\partial s} + s\\right)} \\frac{\\partial\\,f}{\\partial v} + f\\left(t, x, v, a, s\\right) \\frac{\\partial\\,f}{\\partial a} + \\frac{\\partial\\,f}{\\partial t} \\frac{\\partial\\,f}{\\partial s} + \\frac{\\partial^2\\,f}{\\partial t ^ 2}\\right)} \\frac{\\partial^2\\,L}{\\partial s ^ 2} \\end{array}$</div>"}︡{"done":true}{"html":"<div align='center'>$\\displaystyle \\begin{array}{llcl} &amp; M &amp; \\longrightarrow &amp; \\mathbb{R} \\\\ &amp; \\left(t, x, v, a, s\\right) &amp; \\longmapsto &amp; v^{2} \\frac{\\partial^2\\,L}{\\partial s ^ 2} \\frac{\\partial^2\\,f}{\\partial x ^ 2} + {\\left(2 \\, a \\frac{\\partial^2\\,f}{\\partial x\\partial v} + 2 \\, s \\frac{\\partial^2\\,f}{\\partial x\\partial a} + 2 \\, f\\left(t, x, v, a, s\\right) \\frac{\\partial^2\\,f}{\\partial x\\partial s} + \\frac{\\partial\\,f}{\\partial x} \\frac{\\partial\\,f}{\\partial s} + 2 \\, \\frac{\\partial^2\\,f}{\\partial t\\partial x}\\right)} v \\frac{\\partial^2\\,L}{\\partial s ^ 2} + {\\left(a^{2} \\frac{\\partial^2\\,f}{\\partial v ^ 2} + 2 \\, a s \\frac{\\partial^2\\,f}{\\partial v\\partial a} + 2 \\, a f\\left(t, x, v, a, s\\right) \\frac{\\partial^2\\,f}{\\partial v\\partial s} + s^{2} \\frac{\\partial^2\\,f}{\\partial a ^ 2} + 2 \\, s f\\left(t, x, v, a, s\\right) \\frac{\\partial^2\\,f}{\\partial a\\partial s} + s \\frac{\\partial\\,f}{\\partial a} \\frac{\\partial\\,f}{\\partial s} + f\\left(t, x, v, a, s\\right) \\frac{\\partial\\,f}{\\partial s}^{2} + f\\left(t, x, v, a, s\\right)^{2} \\frac{\\partial^2\\,f}{\\partial s ^ 2} + 2 \\, a \\frac{\\partial^2\\,f}{\\partial t\\partial v} + 2 \\, s \\frac{\\partial^2\\,f}{\\partial t\\partial a} + 2 \\, f\\left(t, x, v, a, s\\right) \\frac{\\partial^2\\,f}{\\partial t\\partial s} + a \\frac{\\partial\\,f}{\\partial x} + {\\left(a \\frac{\\partial\\,f}{\\partial s} + s\\right)} \\frac{\\partial\\,f}{\\partial v} + f\\left(t, x, v, a, s\\right) \\frac{\\partial\\,f}{\\partial a} + \\frac{\\partial\\,f}{\\partial t} \\frac{\\partial\\,f}{\\partial s} + \\frac{\\partial^2\\,f}{\\partial t ^ 2}\\right)} \\frac{\\partial^2\\,L}{\\partial s ^ 2} \\end{array}$</div>"}︡{"done":true}︡
︠364c9ec7-a262-4e41-b526-76fdbb808ebbi︠
%md
After removing the term $c2$ above, the remaining terms are at most first-order in $f$.
︡b94f1981-a389-4276-9041-aec6f49bc7e3︡{"done":true,"md":"After removing the term $c2$ above, the remaining terms are at most first-order in $f$."}
︠0ffee7d3-f9ef-4923-b4e0-52189bc33a0b︠
eq1a = eq1-c2; eq1a.display()
︡48f0dba9-de72-49f8-b690-646ff202b0c9︡{"html": "<html><script type=\"math/tex; mode=display\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}\\begin{array}{llcl} & M & \\longrightarrow & \\mathbb{R} \\\\ & \\left(t, x, v, a, s\\right) & \\longmapsto & v^{3} \\frac{\\partial^4\\,L}{\\partial x ^ 3\\partial s} + a^{3} \\frac{\\partial^4\\,L}{\\partial v ^ 3\\partial s} + 3 \\, a^{2} s \\frac{\\partial^4\\,L}{\\partial v ^ 2\\partial a\\partial s} + 3 \\, a^{2} f\\left(t, x, v, a, s\\right) \\frac{\\partial^4\\,L}{\\partial v ^ 2\\partial s ^ 2} + 3 \\, a s^{2} \\frac{\\partial^4\\,L}{\\partial v\\partial a ^ 2\\partial s} + 6 \\, a s f\\left(t, x, v, a, s\\right) \\frac{\\partial^4\\,L}{\\partial v\\partial a\\partial s ^ 2} + 3 \\, a f\\left(t, x, v, a, s\\right)^{2} \\frac{\\partial^4\\,L}{\\partial v\\partial s ^ 3} + s^{3} \\frac{\\partial^4\\,L}{\\partial a ^ 3\\partial s} + 3 \\, s^{2} f\\left(t, x, v, a, s\\right) \\frac{\\partial^4\\,L}{\\partial a ^ 2\\partial s ^ 2} + 3 \\, s f\\left(t, x, v, a, s\\right)^{2} \\frac{\\partial^4\\,L}{\\partial a\\partial s ^ 3} + f\\left(t, x, v, a, s\\right)^{3} \\frac{\\partial^4\\,L}{\\partial s ^ 4} + {\\left(3 \\, a \\frac{\\partial^4\\,L}{\\partial x ^ 2\\partial v\\partial s} + 3 \\, s \\frac{\\partial^4\\,L}{\\partial x ^ 2\\partial a\\partial s} + 3 \\, f\\left(t, x, v, a, s\\right) \\frac{\\partial^4\\,L}{\\partial x ^ 2\\partial s ^ 2} + 3 \\, \\frac{\\partial^3\\,L}{\\partial x\\partial s ^ 2} \\frac{\\partial\\,f}{\\partial x} + 3 \\, \\frac{\\partial^4\\,L}{\\partial t\\partial x ^ 2\\partial s} - \\frac{\\partial^3\\,L}{\\partial x ^ 2\\partial a}\\right)} v^{2} + 3 \\, a^{2} \\frac{\\partial^4\\,L}{\\partial t\\partial v ^ 2\\partial s} + 6 \\, a s \\frac{\\partial^4\\,L}{\\partial t\\partial v\\partial a\\partial s} + 6 \\, a f\\left(t, x, v, a, s\\right) \\frac{\\partial^4\\,L}{\\partial t\\partial v\\partial s ^ 2} + 3 \\, s^{2} \\frac{\\partial^4\\,L}{\\partial t\\partial a ^ 2\\partial s} + 6 \\, s f\\left(t, x, v, a, s\\right) \\frac{\\partial^4\\,L}{\\partial t\\partial a\\partial s ^ 2} + 3 \\, f\\left(t, x, v, a, s\\right)^{2} \\frac{\\partial^4\\,L}{\\partial t\\partial s ^ 3} + 3 \\, a^{2} \\frac{\\partial^3\\,L}{\\partial x\\partial v\\partial s} + 3 \\, a s \\frac{\\partial^3\\,L}{\\partial x\\partial a\\partial s} + 3 \\, a f\\left(t, x, v, a, s\\right) \\frac{\\partial^3\\,L}{\\partial x\\partial s ^ 2} - a^{2} \\frac{\\partial^3\\,L}{\\partial v ^ 2\\partial a} + 3 \\, a s \\frac{\\partial^3\\,L}{\\partial v ^ 2\\partial s} - 2 \\, a s \\frac{\\partial^3\\,L}{\\partial v\\partial a ^ 2} - s^{2} \\frac{\\partial^3\\,L}{\\partial a ^ 3} + s f\\left(t, x, v, a, s\\right) \\frac{\\partial^3\\,L}{\\partial a ^ 2\\partial s} + {\\left(3 \\, a^{2} \\frac{\\partial^4\\,L}{\\partial x\\partial v ^ 2\\partial s} + 6 \\, a s \\frac{\\partial^4\\,L}{\\partial x\\partial v\\partial a\\partial s} + 6 \\, a f\\left(t, x, v, a, s\\right) \\frac{\\partial^4\\,L}{\\partial x\\partial v\\partial s ^ 2} + 3 \\, s^{2} \\frac{\\partial^4\\,L}{\\partial x\\partial a ^ 2\\partial s} + 6 \\, s f\\left(t, x, v, a, s\\right) \\frac{\\partial^4\\,L}{\\partial x\\partial a\\partial s ^ 2} + 3 \\, f\\left(t, x, v, a, s\\right)^{2} \\frac{\\partial^4\\,L}{\\partial x\\partial s ^ 3} + 3 \\, a \\frac{\\partial^3\\,L}{\\partial v\\partial s ^ 2} \\frac{\\partial\\,f}{\\partial x} + 3 \\, s \\frac{\\partial^3\\,L}{\\partial a\\partial s ^ 2} \\frac{\\partial\\,f}{\\partial x} + 3 \\, f\\left(t, x, v, a, s\\right) \\frac{\\partial^3\\,L}{\\partial s ^ 3} \\frac{\\partial\\,f}{\\partial x} + 6 \\, a \\frac{\\partial^4\\,L}{\\partial t\\partial x\\partial v\\partial s} + 6 \\, s \\frac{\\partial^4\\,L}{\\partial t\\partial x\\partial a\\partial s} + 6 \\, f\\left(t, x, v, a, s\\right) \\frac{\\partial^4\\,L}{\\partial t\\partial x\\partial s ^ 2} + 3 \\, a \\frac{\\partial^3\\,L}{\\partial x ^ 2\\partial s} - 2 \\, a \\frac{\\partial^3\\,L}{\\partial x\\partial v\\partial a} + 3 \\, s \\frac{\\partial^3\\,L}{\\partial x\\partial v\\partial s} - 2 \\, s \\frac{\\partial^3\\,L}{\\partial x\\partial a ^ 2} + f\\left(t, x, v, a, s\\right) \\frac{\\partial^3\\,L}{\\partial x\\partial a\\partial s} + 3 \\, {\\left(a \\frac{\\partial\\,f}{\\partial v} + s \\frac{\\partial\\,f}{\\partial a} + f\\left(t, x, v, a, s\\right) \\frac{\\partial\\,f}{\\partial s} + \\frac{\\partial\\,f}{\\partial t}\\right)} \\frac{\\partial^3\\,L}{\\partial x\\partial s ^ 2} + 3 \\, \\frac{\\partial^3\\,L}{\\partial t\\partial s ^ 2} \\frac{\\partial\\,f}{\\partial x} + 3 \\, \\frac{\\partial^4\\,L}{\\partial t ^ 2\\partial x\\partial s} - 2 \\, \\frac{\\partial^3\\,L}{\\partial t\\partial x\\partial a} + \\frac{\\partial^2\\,L}{\\partial x\\partial v}\\right)} v + 3 \\, a \\frac{\\partial^4\\,L}{\\partial t ^ 2\\partial v\\partial s} + 3 \\, s \\frac{\\partial^4\\,L}{\\partial t ^ 2\\partial a\\partial s} + 3 \\, f\\left(t, x, v, a, s\\right) \\frac{\\partial^4\\,L}{\\partial t ^ 2\\partial s ^ 2} + 3 \\, a \\frac{\\partial^3\\,L}{\\partial t\\partial x\\partial s} - 2 \\, a \\frac{\\partial^3\\,L}{\\partial t\\partial v\\partial a} + 3 \\, s \\frac{\\partial^3\\,L}{\\partial t\\partial v\\partial s} - 2 \\, s \\frac{\\partial^3\\,L}{\\partial t\\partial a ^ 2} + f\\left(t, x, v, a, s\\right) \\frac{\\partial^3\\,L}{\\partial t\\partial a\\partial s} + 3 \\, {\\left(a \\frac{\\partial\\,f}{\\partial v} + s \\frac{\\partial\\,f}{\\partial a} + f\\left(t, x, v, a, s\\right) \\frac{\\partial\\,f}{\\partial s} + \\frac{\\partial\\,f}{\\partial t}\\right)} \\frac{\\partial^3\\,L}{\\partial t\\partial s ^ 2} - a \\frac{\\partial^2\\,L}{\\partial x\\partial a} + s \\frac{\\partial^2\\,L}{\\partial x\\partial s} + a \\frac{\\partial^2\\,L}{\\partial v ^ 2} + {\\left(3 \\, s^{2} + a f\\left(t, x, v, a, s\\right)\\right)} \\frac{\\partial^3\\,L}{\\partial v\\partial a\\partial s} + 2 \\, f\\left(t, x, v, a, s\\right) \\frac{\\partial^2\\,L}{\\partial v\\partial s} + 3 \\, {\\left(a^{2} \\frac{\\partial\\,f}{\\partial v} + a s \\frac{\\partial\\,f}{\\partial a} + a f\\left(t, x, v, a, s\\right) \\frac{\\partial\\,f}{\\partial s} + s f\\left(t, x, v, a, s\\right) + a \\frac{\\partial\\,f}{\\partial t}\\right)} \\frac{\\partial^3\\,L}{\\partial v\\partial s ^ 2} - f\\left(t, x, v, a, s\\right) \\frac{\\partial^2\\,L}{\\partial a ^ 2} + {\\left(3 \\, a s \\frac{\\partial\\,f}{\\partial v} + 3 \\, s^{2} \\frac{\\partial\\,f}{\\partial a} + 3 \\, s f\\left(t, x, v, a, s\\right) \\frac{\\partial\\,f}{\\partial s} + 2 \\, f\\left(t, x, v, a, s\\right)^{2} + 3 \\, s \\frac{\\partial\\,f}{\\partial t}\\right)} \\frac{\\partial^3\\,L}{\\partial a\\partial s ^ 2} + 3 \\, {\\left(a f\\left(t, x, v, a, s\\right) \\frac{\\partial\\,f}{\\partial v} + s f\\left(t, x, v, a, s\\right) \\frac{\\partial\\,f}{\\partial a} + f\\left(t, x, v, a, s\\right)^{2} \\frac{\\partial\\,f}{\\partial s} + f\\left(t, x, v, a, s\\right) \\frac{\\partial\\,f}{\\partial t}\\right)} \\frac{\\partial^3\\,L}{\\partial s ^ 3} + \\frac{\\partial^4\\,L}{\\partial t ^ 3\\partial s} - \\frac{\\partial^3\\,L}{\\partial t ^ 2\\partial a} + \\frac{\\partial^2\\,L}{\\partial t\\partial v} - \\frac{\\partial\\,L}{\\partial x} \\end{array}</script></html>", "done": true}︡
︠0fa5bb86-bb59-48ef-a763-96c11529af81i︠
%md
Similarly the first-order terms arise from $N$ applied to the term $Ds\ f$ in $N(Da(L))$.
︡44ab25cb-a512-413b-83f3-96ee32af5031︡{"done":true,"md":"Similarly the first-order terms arise from $N$ applied to the term $Ds\\ f$ in $N(Da(L))$."}
︠a052995f-4059-41e7-92b6-8d85c614d218︠
N(f).display()
︡0efcc6bf-499a-49e1-9bdc-d3d3d19529ed︡{"html": "<html><script type=\"math/tex; mode=display\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}\\begin{array}{llcl} & M & \\longrightarrow & \\mathbb{R} \\\\ & \\left(t, x, v, a, s\\right) & \\longmapsto & v \\frac{\\partial\\,f}{\\partial x} + a \\frac{\\partial\\,f}{\\partial v} + s \\frac{\\partial\\,f}{\\partial a} + f\\left(t, x, v, a, s\\right) \\frac{\\partial\\,f}{\\partial s} + \\frac{\\partial\\,f}{\\partial t} \\end{array}</script></html>", "done": true}︡
︠1bf726ac-0ae0-4f87-8683-f9e98044fbcci︠
%md
For example:
︡3b48fc9f-47bd-44e0-a75c-47a1d2dd96db︡{"done":true,"md":"For example:"}
︠2ec75c54-0ab4-45c6-9b40-65dce4b78c47︠
t1 = eq1a.expr().coefficient(diff(f.expr(),t))*diff(f.expr(),t); M.scalar_field(t1).display()
︡937a89ef-4575-4e14-be1c-29de4caaee08︡{"html": "<html><script type=\"math/tex; mode=display\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}\\begin{array}{llcl} & M & \\longrightarrow & \\mathbb{R} \\\\ & \\left(t, x, v, a, s\\right) & \\longmapsto & 3 \\, {\\left(v \\frac{\\partial^3\\,L}{\\partial x\\partial s ^ 2} + a \\frac{\\partial^3\\,L}{\\partial v\\partial s ^ 2} + s \\frac{\\partial^3\\,L}{\\partial a\\partial s ^ 2} + f\\left(t, x, v, a, s\\right) \\frac{\\partial^3\\,L}{\\partial s ^ 3} + \\frac{\\partial^3\\,L}{\\partial t\\partial s ^ 2}\\right)} \\frac{\\partial\\,f}{\\partial t} \\end{array}</script></html>", "done": true}︡
︠cbeac39d-cdfe-4308-a455-697458a614cf︠
x1 = eq1a.expr().coefficient(diff(f.expr(),x))*diff(f.expr(),x); M.scalar_field(x1).display()
︡d7aa5ca8-b3bc-4160-af12-bbe2370def56︡{"html": "<html><script type=\"math/tex; mode=display\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}\\begin{array}{llcl} & M & \\longrightarrow & \\mathbb{R} \\\\ & \\left(t, x, v, a, s\\right) & \\longmapsto & 3 \\, {\\left(v^{2} \\frac{\\partial^3\\,L}{\\partial x\\partial s ^ 2} + {\\left(a \\frac{\\partial^3\\,L}{\\partial v\\partial s ^ 2} + s \\frac{\\partial^3\\,L}{\\partial a\\partial s ^ 2} + f\\left(t, x, v, a, s\\right) \\frac{\\partial^3\\,L}{\\partial s ^ 3} + \\frac{\\partial^3\\,L}{\\partial t\\partial s ^ 2}\\right)} v\\right)} \\frac{\\partial\\,f}{\\partial x} \\end{array}</script></html>", "done": true}︡
︠cfd45861-c951-484e-91a3-1411d10233a0︠
v1 = eq1a.expr().coefficient(diff(f.expr(),v))*diff(f.expr(),v); M.scalar_field(v1).display()
︡26aee3bb-dffc-40ae-8b38-9ad438c4f351︡{"html": "<html><script type=\"math/tex; mode=display\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}\\begin{array}{llcl} & M & \\longrightarrow & \\mathbb{R} \\\\ & \\left(t, x, v, a, s\\right) & \\longmapsto & 3 \\, {\\left(a v \\frac{\\partial^3\\,L}{\\partial x\\partial s ^ 2} + a^{2} \\frac{\\partial^3\\,L}{\\partial v\\partial s ^ 2} + a s \\frac{\\partial^3\\,L}{\\partial a\\partial s ^ 2} + a f\\left(t, x, v, a, s\\right) \\frac{\\partial^3\\,L}{\\partial s ^ 3} + a \\frac{\\partial^3\\,L}{\\partial t\\partial s ^ 2}\\right)} \\frac{\\partial\\,f}{\\partial v} \\end{array}</script></html>", "done": true}︡
︠c9586021-bc5d-4343-ac58-9b35834fb1c3︠
a1 = eq1a.expr().coefficient(diff(f.expr(),a))*diff(f.expr(),a); M.scalar_field(a1).display()
︡3e3b567d-8086-41fd-b627-19c9b9da2fd3︡{"html": "<html><script type=\"math/tex; mode=display\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}\\begin{array}{llcl} & M & \\longrightarrow & \\mathbb{R} \\\\ & \\left(t, x, v, a, s\\right) & \\longmapsto & 3 \\, {\\left(s v \\frac{\\partial^3\\,L}{\\partial x\\partial s ^ 2} + a s \\frac{\\partial^3\\,L}{\\partial v\\partial s ^ 2} + s^{2} \\frac{\\partial^3\\,L}{\\partial a\\partial s ^ 2} + s f\\left(t, x, v, a, s\\right) \\frac{\\partial^3\\,L}{\\partial s ^ 3} + s \\frac{\\partial^3\\,L}{\\partial t\\partial s ^ 2}\\right)} \\frac{\\partial\\,f}{\\partial a} \\end{array}</script></html>", "done": true}︡
︠115b18e6-1dc6-4d99-ad2f-6baa97d5413b︠
s1 = eq1a.expr().coefficient(diff(f.expr(),s))*diff(f.expr(),s); M.scalar_field(s1).display()
︡04a0e170-8b90-4bd5-8934-38f3967c6580︡{"html": "<html><script type=\"math/tex; mode=display\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}\\begin{array}{llcl} & M & \\longrightarrow & \\mathbb{R} \\\\ & \\left(t, x, v, a, s\\right) & \\longmapsto & 3 \\, {\\left(v f\\left(t, x, v, a, s\\right) \\frac{\\partial^3\\,L}{\\partial x\\partial s ^ 2} + a f\\left(t, x, v, a, s\\right) \\frac{\\partial^3\\,L}{\\partial v\\partial s ^ 2} + s f\\left(t, x, v, a, s\\right) \\frac{\\partial^3\\,L}{\\partial a\\partial s ^ 2} + f\\left(t, x, v, a, s\\right)^{2} \\frac{\\partial^3\\,L}{\\partial s ^ 3} + f\\left(t, x, v, a, s\\right) \\frac{\\partial^3\\,L}{\\partial t\\partial s ^ 2}\\right)} \\frac{\\partial\\,f}{\\partial s} \\end{array}</script></html>", "done": true}︡
︠89389499-4146-468f-b166-263bae42a652i︠
%md
Liebniz rule applies $N$ to these coefficients.
︡869a297e-9128-4ed6-81ef-16afbdba701e︡{"done":true,"md":"Liebniz rule applies $N$ to these coefficients."}
︠1be50ef9-e8e1-4e5d-9a74-01872e61e141︠
c1 = 3*N(Ds(Ds(L)))*N(f); c1.display()
︡d02a5152-5acb-4d5d-9c53-363e069feb3f︡{"html": "<html><script type=\"math/tex; mode=display\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}\\begin{array}{llcl} & M & \\longrightarrow & \\mathbb{R} \\\\ & \\left(t, x, v, a, s\\right) & \\longmapsto & 3 \\, v^{2} \\frac{\\partial^3\\,L}{\\partial x\\partial s ^ 2} \\frac{\\partial\\,f}{\\partial x} + 3 \\, {\\left(a \\frac{\\partial^3\\,L}{\\partial v\\partial s ^ 2} \\frac{\\partial\\,f}{\\partial x} + s \\frac{\\partial^3\\,L}{\\partial a\\partial s ^ 2} \\frac{\\partial\\,f}{\\partial x} + f\\left(t, x, v, a, s\\right) \\frac{\\partial^3\\,L}{\\partial s ^ 3} \\frac{\\partial\\,f}{\\partial x} + {\\left(a \\frac{\\partial\\,f}{\\partial v} + s \\frac{\\partial\\,f}{\\partial a} + f\\left(t, x, v, a, s\\right) \\frac{\\partial\\,f}{\\partial s} + \\frac{\\partial\\,f}{\\partial t}\\right)} \\frac{\\partial^3\\,L}{\\partial x\\partial s ^ 2} + \\frac{\\partial^3\\,L}{\\partial t\\partial s ^ 2} \\frac{\\partial\\,f}{\\partial x}\\right)} v + 3 \\, {\\left(a \\frac{\\partial\\,f}{\\partial v} + s \\frac{\\partial\\,f}{\\partial a} + f\\left(t, x, v, a, s\\right) \\frac{\\partial\\,f}{\\partial s} + \\frac{\\partial\\,f}{\\partial t}\\right)} \\frac{\\partial^3\\,L}{\\partial t\\partial s ^ 2} + 3 \\, {\\left(a^{2} \\frac{\\partial\\,f}{\\partial v} + a s \\frac{\\partial\\,f}{\\partial a} + a f\\left(t, x, v, a, s\\right) \\frac{\\partial\\,f}{\\partial s} + a \\frac{\\partial\\,f}{\\partial t}\\right)} \\frac{\\partial^3\\,L}{\\partial v\\partial s ^ 2} + 3 \\, {\\left(a s \\frac{\\partial\\,f}{\\partial v} + s^{2} \\frac{\\partial\\,f}{\\partial a} + s f\\left(t, x, v, a, s\\right) \\frac{\\partial\\,f}{\\partial s} + s \\frac{\\partial\\,f}{\\partial t}\\right)} \\frac{\\partial^3\\,L}{\\partial a\\partial s ^ 2} + 3 \\, {\\left(a f\\left(t, x, v, a, s\\right) \\frac{\\partial\\,f}{\\partial v} + s f\\left(t, x, v, a, s\\right) \\frac{\\partial\\,f}{\\partial a} + f\\left(t, x, v, a, s\\right)^{2} \\frac{\\partial\\,f}{\\partial s} + f\\left(t, x, v, a, s\\right) \\frac{\\partial\\,f}{\\partial t}\\right)} \\frac{\\partial^3\\,L}{\\partial s ^ 3} \\end{array}</script></html>", "done": true}︡
︠bc24740c-7665-49a0-84de-ef3484b8dbf6︠
bool(c1.expr()==t1+x1+v1+a1+s1)
︡bbf05245-2c36-481f-94eb-f5fe73fbb228︡{"html": "<html><script type=\"math/tex; mode=display\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}\\mathrm{True}</script></html>", "done": true}︡
︠6079e255-57e8-4d38-a49c-765874b013c1i︠
%md
Removing the 1$^\textit{st}$ order terms:
︡51fb7a96-9f84-47b5-b3bd-a1c4157120a9︡{"done":true,"md":"Removing the 1$^\\textit{st}$ order terms:"}
︠d531d89f-83ec-4b5a-8dd7-1eedee86f81b︠
eq1b = eq1a-c1; eq1b.display()
︡585f2a31-0a2b-4ed2-b91f-3cbe7b3dbabc︡{"html": "<html><script type=\"math/tex; mode=display\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}\\begin{array}{llcl} & M & \\longrightarrow & \\mathbb{R} \\\\ & \\left(t, x, v, a, s\\right) & \\longmapsto & v^{3} \\frac{\\partial^4\\,L}{\\partial x ^ 3\\partial s} + a^{3} \\frac{\\partial^4\\,L}{\\partial v ^ 3\\partial s} + 3 \\, a^{2} s \\frac{\\partial^4\\,L}{\\partial v ^ 2\\partial a\\partial s} + 3 \\, a^{2} f\\left(t, x, v, a, s\\right) \\frac{\\partial^4\\,L}{\\partial v ^ 2\\partial s ^ 2} + 3 \\, a s^{2} \\frac{\\partial^4\\,L}{\\partial v\\partial a ^ 2\\partial s} + 6 \\, a s f\\left(t, x, v, a, s\\right) \\frac{\\partial^4\\,L}{\\partial v\\partial a\\partial s ^ 2} + 3 \\, a f\\left(t, x, v, a, s\\right)^{2} \\frac{\\partial^4\\,L}{\\partial v\\partial s ^ 3} + s^{3} \\frac{\\partial^4\\,L}{\\partial a ^ 3\\partial s} + 3 \\, s^{2} f\\left(t, x, v, a, s\\right) \\frac{\\partial^4\\,L}{\\partial a ^ 2\\partial s ^ 2} + 3 \\, s f\\left(t, x, v, a, s\\right)^{2} \\frac{\\partial^4\\,L}{\\partial a\\partial s ^ 3} + f\\left(t, x, v, a, s\\right)^{3} \\frac{\\partial^4\\,L}{\\partial s ^ 4} + {\\left(3 \\, a \\frac{\\partial^4\\,L}{\\partial x ^ 2\\partial v\\partial s} + 3 \\, s \\frac{\\partial^4\\,L}{\\partial x ^ 2\\partial a\\partial s} + 3 \\, f\\left(t, x, v, a, s\\right) \\frac{\\partial^4\\,L}{\\partial x ^ 2\\partial s ^ 2} + 3 \\, \\frac{\\partial^4\\,L}{\\partial t\\partial x ^ 2\\partial s} - \\frac{\\partial^3\\,L}{\\partial x ^ 2\\partial a}\\right)} v^{2} + 3 \\, a^{2} \\frac{\\partial^4\\,L}{\\partial t\\partial v ^ 2\\partial s} + 6 \\, a s \\frac{\\partial^4\\,L}{\\partial t\\partial v\\partial a\\partial s} + 6 \\, a f\\left(t, x, v, a, s\\right) \\frac{\\partial^4\\,L}{\\partial t\\partial v\\partial s ^ 2} + 3 \\, s^{2} \\frac{\\partial^4\\,L}{\\partial t\\partial a ^ 2\\partial s} + 6 \\, s f\\left(t, x, v, a, s\\right) \\frac{\\partial^4\\,L}{\\partial t\\partial a\\partial s ^ 2} + 3 \\, f\\left(t, x, v, a, s\\right)^{2} \\frac{\\partial^4\\,L}{\\partial t\\partial s ^ 3} + 3 \\, a^{2} \\frac{\\partial^3\\,L}{\\partial x\\partial v\\partial s} + 3 \\, a s \\frac{\\partial^3\\,L}{\\partial x\\partial a\\partial s} + 3 \\, a f\\left(t, x, v, a, s\\right) \\frac{\\partial^3\\,L}{\\partial x\\partial s ^ 2} - a^{2} \\frac{\\partial^3\\,L}{\\partial v ^ 2\\partial a} + 3 \\, a s \\frac{\\partial^3\\,L}{\\partial v ^ 2\\partial s} - 2 \\, a s \\frac{\\partial^3\\,L}{\\partial v\\partial a ^ 2} + 3 \\, s f\\left(t, x, v, a, s\\right) \\frac{\\partial^3\\,L}{\\partial v\\partial s ^ 2} - s^{2} \\frac{\\partial^3\\,L}{\\partial a ^ 3} + s f\\left(t, x, v, a, s\\right) \\frac{\\partial^3\\,L}{\\partial a ^ 2\\partial s} + 2 \\, f\\left(t, x, v, a, s\\right)^{2} \\frac{\\partial^3\\,L}{\\partial a\\partial s ^ 2} + {\\left(3 \\, a^{2} \\frac{\\partial^4\\,L}{\\partial x\\partial v ^ 2\\partial s} + 6 \\, a s \\frac{\\partial^4\\,L}{\\partial x\\partial v\\partial a\\partial s} + 6 \\, a f\\left(t, x, v, a, s\\right) \\frac{\\partial^4\\,L}{\\partial x\\partial v\\partial s ^ 2} + 3 \\, s^{2} \\frac{\\partial^4\\,L}{\\partial x\\partial a ^ 2\\partial s} + 6 \\, s f\\left(t, x, v, a, s\\right) \\frac{\\partial^4\\,L}{\\partial x\\partial a\\partial s ^ 2} + 3 \\, f\\left(t, x, v, a, s\\right)^{2} \\frac{\\partial^4\\,L}{\\partial x\\partial s ^ 3} + 6 \\, a \\frac{\\partial^4\\,L}{\\partial t\\partial x\\partial v\\partial s} + 6 \\, s \\frac{\\partial^4\\,L}{\\partial t\\partial x\\partial a\\partial s} + 6 \\, f\\left(t, x, v, a, s\\right) \\frac{\\partial^4\\,L}{\\partial t\\partial x\\partial s ^ 2} + 3 \\, a \\frac{\\partial^3\\,L}{\\partial x ^ 2\\partial s} - 2 \\, a \\frac{\\partial^3\\,L}{\\partial x\\partial v\\partial a} + 3 \\, s \\frac{\\partial^3\\,L}{\\partial x\\partial v\\partial s} - 2 \\, s \\frac{\\partial^3\\,L}{\\partial x\\partial a ^ 2} + f\\left(t, x, v, a, s\\right) \\frac{\\partial^3\\,L}{\\partial x\\partial a\\partial s} + 3 \\, \\frac{\\partial^4\\,L}{\\partial t ^ 2\\partial x\\partial s} - 2 \\, \\frac{\\partial^3\\,L}{\\partial t\\partial x\\partial a} + \\frac{\\partial^2\\,L}{\\partial x\\partial v}\\right)} v + 3 \\, a \\frac{\\partial^4\\,L}{\\partial t ^ 2\\partial v\\partial s} + 3 \\, s \\frac{\\partial^4\\,L}{\\partial t ^ 2\\partial a\\partial s} + 3 \\, f\\left(t, x, v, a, s\\right) \\frac{\\partial^4\\,L}{\\partial t ^ 2\\partial s ^ 2} + 3 \\, a \\frac{\\partial^3\\,L}{\\partial t\\partial x\\partial s} - 2 \\, a \\frac{\\partial^3\\,L}{\\partial t\\partial v\\partial a} + 3 \\, s \\frac{\\partial^3\\,L}{\\partial t\\partial v\\partial s} - 2 \\, s \\frac{\\partial^3\\,L}{\\partial t\\partial a ^ 2} + f\\left(t, x, v, a, s\\right) \\frac{\\partial^3\\,L}{\\partial t\\partial a\\partial s} - a \\frac{\\partial^2\\,L}{\\partial x\\partial a} + s \\frac{\\partial^2\\,L}{\\partial x\\partial s} + a \\frac{\\partial^2\\,L}{\\partial v ^ 2} + {\\left(3 \\, s^{2} + a f\\left(t, x, v, a, s\\right)\\right)} \\frac{\\partial^3\\,L}{\\partial v\\partial a\\partial s} + 2 \\, f\\left(t, x, v, a, s\\right) \\frac{\\partial^2\\,L}{\\partial v\\partial s} - f\\left(t, x, v, a, s\\right) \\frac{\\partial^2\\,L}{\\partial a ^ 2} + \\frac{\\partial^4\\,L}{\\partial t ^ 3\\partial s} - \\frac{\\partial^3\\,L}{\\partial t ^ 2\\partial a} + \\frac{\\partial^2\\,L}{\\partial t\\partial v} - \\frac{\\partial\\,L}{\\partial x} \\end{array}</script></html>", "done": true}︡
︠7bf80f48-a23a-43f8-b9f2-69e009ba4e74i︠
%md
Only terms algebraic in $f$ remain. The number of terms is:
︡ca43cd26-f846-4cc0-93bc-9c5047c9dcdf︡{"done":true,"md":"Only terms algebraic in $f$ remain. The number of terms is:"}
︠619d0277-beba-47fa-84e4-bc9a9eca6281︠
len(eq1b.expr().expand())
︡4aca041e-a956-42ed-947f-9298f11284e8︡{"html": "<html><script type=\"math/tex; mode=display\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}68</script></html>", "done": true}︡
︠ede22444-0ff2-4706-b49e-98ea225decabi︠
%md
The term of highest degree comes from $N^3$ applied to $Ds(L)$:
︡43037afe-94a4-46aa-b6c5-dc60e288f30e︡{"done":true,"md":"The term of highest degree comes from $N^3$ applied to $Ds(L)$:"}
︠955ede37-b414-4172-a02f-c9f108e89452︠
t0 = eq1b.expr().coefficient(f.expr()^3)*f.expr()^3; M.scalar_field(t0.expand()).display()
︡aed27ec5-83c8-40c5-b70b-f6b55fef5ac0︡{"html": "<html><script type=\"math/tex; mode=display\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}\\begin{array}{llcl} & M & \\longrightarrow & \\mathbb{R} \\\\ & \\left(t, x, v, a, s\\right) & \\longmapsto & f\\left(t, x, v, a, s\\right)^{3} \\frac{\\partial^4\\,L}{\\partial s ^ 4} \\end{array}</script></html>", "done": true}︡
︠4a8aa6bd-0ac8-4514-80e9-22d6e69fb221︠
cf3 = Ds(Ds(Ds(Ds(L))))*f^3; cf3.display()
︡e4e89407-39a5-467d-b7fa-77bc064dd572︡{"html": "<html><script type=\"math/tex; mode=display\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}\\begin{array}{llcl} & M & \\longrightarrow & \\mathbb{R} \\\\ & \\left(t, x, v, a, s\\right) & \\longmapsto & f\\left(t, x, v, a, s\\right)^{3} \\frac{\\partial^4\\,L}{\\partial s ^ 4} \\end{array}</script></html>", "done": true}︡
︠1a444bbb-6079-4eeb-963b-0f582acacb0fi︠
%md
Removing the 3$^{rd}$ degree term:
︡e647ce49-0db1-4d9d-8748-ca2df8a4e4b0︡{"done":true,"md":"Removing the 3$^{rd}$ degree term:"}
︠5a1b82ab-41fd-4be7-80e6-9c32a79e304e︠
eq1c = eq1b-cf3; eq1c.display()
︡9e6c5be2-5f63-42f5-9461-fdbec6b33d73︡{"html": "<html><script type=\"math/tex; mode=display\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}\\begin{array}{llcl} & M & \\longrightarrow & \\mathbb{R} \\\\ & \\left(t, x, v, a, s\\right) & \\longmapsto & v^{3} \\frac{\\partial^4\\,L}{\\partial x ^ 3\\partial s} + a^{3} \\frac{\\partial^4\\,L}{\\partial v ^ 3\\partial s} + 3 \\, a^{2} s \\frac{\\partial^4\\,L}{\\partial v ^ 2\\partial a\\partial s} + 3 \\, a^{2} f\\left(t, x, v, a, s\\right) \\frac{\\partial^4\\,L}{\\partial v ^ 2\\partial s ^ 2} + 3 \\, a s^{2} \\frac{\\partial^4\\,L}{\\partial v\\partial a ^ 2\\partial s} + 6 \\, a s f\\left(t, x, v, a, s\\right) \\frac{\\partial^4\\,L}{\\partial v\\partial a\\partial s ^ 2} + 3 \\, a f\\left(t, x, v, a, s\\right)^{2} \\frac{\\partial^4\\,L}{\\partial v\\partial s ^ 3} + s^{3} \\frac{\\partial^4\\,L}{\\partial a ^ 3\\partial s} + 3 \\, s^{2} f\\left(t, x, v, a, s\\right) \\frac{\\partial^4\\,L}{\\partial a ^ 2\\partial s ^ 2} + 3 \\, s f\\left(t, x, v, a, s\\right)^{2} \\frac{\\partial^4\\,L}{\\partial a\\partial s ^ 3} + {\\left(3 \\, a \\frac{\\partial^4\\,L}{\\partial x ^ 2\\partial v\\partial s} + 3 \\, s \\frac{\\partial^4\\,L}{\\partial x ^ 2\\partial a\\partial s} + 3 \\, f\\left(t, x, v, a, s\\right) \\frac{\\partial^4\\,L}{\\partial x ^ 2\\partial s ^ 2} + 3 \\, \\frac{\\partial^4\\,L}{\\partial t\\partial x ^ 2\\partial s} - \\frac{\\partial^3\\,L}{\\partial x ^ 2\\partial a}\\right)} v^{2} + 3 \\, a^{2} \\frac{\\partial^4\\,L}{\\partial t\\partial v ^ 2\\partial s} + 6 \\, a s \\frac{\\partial^4\\,L}{\\partial t\\partial v\\partial a\\partial s} + 6 \\, a f\\left(t, x, v, a, s\\right) \\frac{\\partial^4\\,L}{\\partial t\\partial v\\partial s ^ 2} + 3 \\, s^{2} \\frac{\\partial^4\\,L}{\\partial t\\partial a ^ 2\\partial s} + 6 \\, s f\\left(t, x, v, a, s\\right) \\frac{\\partial^4\\,L}{\\partial t\\partial a\\partial s ^ 2} + 3 \\, f\\left(t, x, v, a, s\\right)^{2} \\frac{\\partial^4\\,L}{\\partial t\\partial s ^ 3} + 3 \\, a^{2} \\frac{\\partial^3\\,L}{\\partial x\\partial v\\partial s} + 3 \\, a s \\frac{\\partial^3\\,L}{\\partial x\\partial a\\partial s} + 3 \\, a f\\left(t, x, v, a, s\\right) \\frac{\\partial^3\\,L}{\\partial x\\partial s ^ 2} - a^{2} \\frac{\\partial^3\\,L}{\\partial v ^ 2\\partial a} + 3 \\, a s \\frac{\\partial^3\\,L}{\\partial v ^ 2\\partial s} - 2 \\, a s \\frac{\\partial^3\\,L}{\\partial v\\partial a ^ 2} + 3 \\, s f\\left(t, x, v, a, s\\right) \\frac{\\partial^3\\,L}{\\partial v\\partial s ^ 2} - s^{2} \\frac{\\partial^3\\,L}{\\partial a ^ 3} + s f\\left(t, x, v, a, s\\right) \\frac{\\partial^3\\,L}{\\partial a ^ 2\\partial s} + 2 \\, f\\left(t, x, v, a, s\\right)^{2} \\frac{\\partial^3\\,L}{\\partial a\\partial s ^ 2} + {\\left(3 \\, a^{2} \\frac{\\partial^4\\,L}{\\partial x\\partial v ^ 2\\partial s} + 6 \\, a s \\frac{\\partial^4\\,L}{\\partial x\\partial v\\partial a\\partial s} + 6 \\, a f\\left(t, x, v, a, s\\right) \\frac{\\partial^4\\,L}{\\partial x\\partial v\\partial s ^ 2} + 3 \\, s^{2} \\frac{\\partial^4\\,L}{\\partial x\\partial a ^ 2\\partial s} + 6 \\, s f\\left(t, x, v, a, s\\right) \\frac{\\partial^4\\,L}{\\partial x\\partial a\\partial s ^ 2} + 3 \\, f\\left(t, x, v, a, s\\right)^{2} \\frac{\\partial^4\\,L}{\\partial x\\partial s ^ 3} + 6 \\, a \\frac{\\partial^4\\,L}{\\partial t\\partial x\\partial v\\partial s} + 6 \\, s \\frac{\\partial^4\\,L}{\\partial t\\partial x\\partial a\\partial s} + 6 \\, f\\left(t, x, v, a, s\\right) \\frac{\\partial^4\\,L}{\\partial t\\partial x\\partial s ^ 2} + 3 \\, a \\frac{\\partial^3\\,L}{\\partial x ^ 2\\partial s} - 2 \\, a \\frac{\\partial^3\\,L}{\\partial x\\partial v\\partial a} + 3 \\, s \\frac{\\partial^3\\,L}{\\partial x\\partial v\\partial s} - 2 \\, s \\frac{\\partial^3\\,L}{\\partial x\\partial a ^ 2} + f\\left(t, x, v, a, s\\right) \\frac{\\partial^3\\,L}{\\partial x\\partial a\\partial s} + 3 \\, \\frac{\\partial^4\\,L}{\\partial t ^ 2\\partial x\\partial s} - 2 \\, \\frac{\\partial^3\\,L}{\\partial t\\partial x\\partial a} + \\frac{\\partial^2\\,L}{\\partial x\\partial v}\\right)} v + 3 \\, a \\frac{\\partial^4\\,L}{\\partial t ^ 2\\partial v\\partial s} + 3 \\, s \\frac{\\partial^4\\,L}{\\partial t ^ 2\\partial a\\partial s} + 3 \\, f\\left(t, x, v, a, s\\right) \\frac{\\partial^4\\,L}{\\partial t ^ 2\\partial s ^ 2} + 3 \\, a \\frac{\\partial^3\\,L}{\\partial t\\partial x\\partial s} - 2 \\, a \\frac{\\partial^3\\,L}{\\partial t\\partial v\\partial a} + 3 \\, s \\frac{\\partial^3\\,L}{\\partial t\\partial v\\partial s} - 2 \\, s \\frac{\\partial^3\\,L}{\\partial t\\partial a ^ 2} + f\\left(t, x, v, a, s\\right) \\frac{\\partial^3\\,L}{\\partial t\\partial a\\partial s} - a \\frac{\\partial^2\\,L}{\\partial x\\partial a} + s \\frac{\\partial^2\\,L}{\\partial x\\partial s} + a \\frac{\\partial^2\\,L}{\\partial v ^ 2} + {\\left(3 \\, s^{2} + a f\\left(t, x, v, a, s\\right)\\right)} \\frac{\\partial^3\\,L}{\\partial v\\partial a\\partial s} + 2 \\, f\\left(t, x, v, a, s\\right) \\frac{\\partial^2\\,L}{\\partial v\\partial s} - f\\left(t, x, v, a, s\\right) \\frac{\\partial^2\\,L}{\\partial a ^ 2} + \\frac{\\partial^4\\,L}{\\partial t ^ 3\\partial s} - \\frac{\\partial^3\\,L}{\\partial t ^ 2\\partial a} + \\frac{\\partial^2\\,L}{\\partial t\\partial v} - \\frac{\\partial\\,L}{\\partial x} \\end{array}</script></html>", "done": true}︡
︠f8544df5-f9bf-44aa-80c1-bb5283277081i︠
%md
leaves terms of at most 2$^{nd}$ degree. These 2$^{nd}$ degree terms come for $N^2$ applied to $Da(L)$,
︡2d3ee05f-a3fc-40f2-9406-3b694af5c318︡{"done":true,"md":"leaves terms of at most 2$^{nd}$ degree. These 2$^{nd}$ degree terms come for $N^2$ applied to $Da(L)$,"}
︠5e61db6d-83ac-4eb3-8435-d1fd46da4240︠
t0 = eq1c.expr().coefficient(f.expr()^2)*f.expr()^2; M.scalar_field(t0.expand()).display()
︡0757ef24-47c6-4bf7-8676-7eefd41a2779︡{"html": "<html><script type=\"math/tex; mode=display\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}\\begin{array}{llcl} & M & \\longrightarrow & \\mathbb{R} \\\\ & \\left(t, x, v, a, s\\right) & \\longmapsto & 3 \\, v f\\left(t, x, v, a, s\\right)^{2} \\frac{\\partial^4\\,L}{\\partial x\\partial s ^ 3} + 3 \\, a f\\left(t, x, v, a, s\\right)^{2} \\frac{\\partial^4\\,L}{\\partial v\\partial s ^ 3} + 3 \\, s f\\left(t, x, v, a, s\\right)^{2} \\frac{\\partial^4\\,L}{\\partial a\\partial s ^ 3} + 3 \\, f\\left(t, x, v, a, s\\right)^{2} \\frac{\\partial^4\\,L}{\\partial t\\partial s ^ 3} + 2 \\, f\\left(t, x, v, a, s\\right)^{2} \\frac{\\partial^3\\,L}{\\partial a\\partial s ^ 2} \\end{array}</script></html>", "done": true}︡
︠658e8193-5088-4c39-88d8-64c2286669ca︠
cf2 = N(Ds(Da(L)))*f; cf2.display()
︡9ad5cdf0-0df4-4aed-abf1-30169ef06a1f︡{"html": "<html><script type=\"math/tex; mode=display\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}\\begin{array}{llcl} & M & \\longrightarrow & \\mathbb{R} \\\\ & \\left(t, x, v, a, s\\right) & \\longmapsto & v f\\left(t, x, v, a, s\\right) \\frac{\\partial^3\\,L}{\\partial x\\partial a\\partial s} + a f\\left(t, x, v, a, s\\right) \\frac{\\partial^3\\,L}{\\partial v\\partial a\\partial s} + s f\\left(t, x, v, a, s\\right) \\frac{\\partial^3\\,L}{\\partial a ^ 2\\partial s} + f\\left(t, x, v, a, s\\right)^{2} \\frac{\\partial^3\\,L}{\\partial a\\partial s ^ 2} + f\\left(t, x, v, a, s\\right) \\frac{\\partial^3\\,L}{\\partial t\\partial a\\partial s} \\end{array}</script></html>", "done": true}︡
︠fb3bbb1b-bea0-4040-a4d3-c5509a8e7b43︠
cf2 = Ds(Ds(Da(L)))*f^2; cf2.display()
︡c0f53977-c36e-4f5a-8eac-a2809c23d4ba︡{"html": "<html><script type=\"math/tex; mode=display\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}\\begin{array}{llcl} & M & \\longrightarrow & \\mathbb{R} \\\\ & \\left(t, x, v, a, s\\right) & \\longmapsto & f\\left(t, x, v, a, s\\right)^{2} \\frac{\\partial^3\\,L}{\\partial a\\partial s ^ 2} \\end{array}</script></html>", "done": true}︡
︠4558f0e2-4574-46c8-948e-178cef535921i︠
%md
We cannot solve this for `f` algebraically since `f` appears as derivatives.
︡8726b8d7-9812-4739-b594-f40dce3fcffa︡{"done":true,"md":"We cannot solve this for `f` algebraically since `f` appears as derivatives."}
︠60cfdc80-eb0e-4df2-a0b7-2c36277e0f47i︠
%md
## Lagrangian linear in s.
︡50e205bd-06ae-49cc-88f8-0be5da5abfae︡{"done":true,"md":"## Lagrangian linear in s."}
︠8e6cff2c-cec8-4be7-8598-a40494af1131︠
ll=list(coord);ll.remove(s);ll
︡3d272698-ee4e-4548-a776-71e249e54bf2︡{"html": "<html><script type=\"math/tex; mode=display\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}\\left[t, x, v, a\\right]</script></html>", "done": true}︡
︠ee2eb77e-de96-49d5-ac31-a4fbbc68b1f3︠
Ll = M.scalar_field(function('L0')(*ll)) + s * M.scalar_field(function('L1')(*ll)); Ll.display()
︡e21307f4-394d-4ca0-8183-272cc34fd06b︡{"html": "<html><script type=\"math/tex; mode=display\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}\\begin{array}{llcl} & M & \\longrightarrow & \\mathbb{R} \\\\ & \\left(t, x, v, a, s\\right) & \\longmapsto & s L_{1}\\left(t, x, v, a\\right) + L_{0}\\left(t, x, v, a\\right) \\end{array}</script></html>", "done": true}︡
︠2273e28b-a430-442d-bc47-1364fcd32230︠
solve(eq1.expr().substitute_function(L.expr().operator(),Ll.expr().function(*list(coord))),f.expr())[0]
︡a4b1768b-e1c2-47d0-96bb-1526ddd07af6︡{"html": "<html><script type=\"math/tex; mode=display\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}f\\left(t, x, v, a, s\\right) = -\\frac{v^{3} \\frac{\\partial^{3}}{(\\partial x)^{3}}L_{1}\\left(t, x, v, a\\right) + a^{3} \\frac{\\partial^{3}}{(\\partial v)^{3}}L_{1}\\left(t, x, v, a\\right) + 2 \\, a^{2} s \\frac{\\partial^{3}}{(\\partial v)^{2}\\partial a}L_{1}\\left(t, x, v, a\\right) + a s^{2} \\frac{\\partial^{3}}{\\partial v(\\partial a)^{2}}L_{1}\\left(t, x, v, a\\right) + {\\left(3 \\, a \\frac{\\partial^{3}}{(\\partial x)^{2}\\partial v}L_{1}\\left(t, x, v, a\\right) + 2 \\, s \\frac{\\partial^{3}}{(\\partial x)^{2}\\partial a}L_{1}\\left(t, x, v, a\\right) - \\frac{\\partial^{3}}{(\\partial x)^{2}\\partial a}L_{0}\\left(t, x, v, a\\right) + 3 \\, \\frac{\\partial^{3}}{\\partial t(\\partial x)^{2}}L_{1}\\left(t, x, v, a\\right)\\right)} v^{2} - a^{2} \\frac{\\partial^{3}}{(\\partial v)^{2}\\partial a}L_{0}\\left(t, x, v, a\\right) - 2 \\, a s \\frac{\\partial^{3}}{\\partial v(\\partial a)^{2}}L_{0}\\left(t, x, v, a\\right) - s^{2} \\frac{\\partial^{3}}{(\\partial a)^{3}}L_{0}\\left(t, x, v, a\\right) + 3 \\, a^{2} \\frac{\\partial^{3}}{\\partial t(\\partial v)^{2}}L_{1}\\left(t, x, v, a\\right) + 4 \\, a s \\frac{\\partial^{3}}{\\partial t\\partial v\\partial a}L_{1}\\left(t, x, v, a\\right) + s^{2} \\frac{\\partial^{3}}{\\partial t(\\partial a)^{2}}L_{1}\\left(t, x, v, a\\right) + 3 \\, a^{2} \\frac{\\partial^{2}}{\\partial x\\partial v}L_{1}\\left(t, x, v, a\\right) + 2 \\, a s \\frac{\\partial^{2}}{\\partial x\\partial a}L_{1}\\left(t, x, v, a\\right) + 4 \\, a s \\frac{\\partial^{2}}{(\\partial v)^{2}}L_{1}\\left(t, x, v, a\\right) + 3 \\, s^{2} \\frac{\\partial^{2}}{\\partial v\\partial a}L_{1}\\left(t, x, v, a\\right) + {\\left(3 \\, a^{2} \\frac{\\partial^{3}}{\\partial x(\\partial v)^{2}}L_{1}\\left(t, x, v, a\\right) + 4 \\, a s \\frac{\\partial^{3}}{\\partial x\\partial v\\partial a}L_{1}\\left(t, x, v, a\\right) + s^{2} \\frac{\\partial^{3}}{\\partial x(\\partial a)^{2}}L_{1}\\left(t, x, v, a\\right) - 2 \\, a \\frac{\\partial^{3}}{\\partial x\\partial v\\partial a}L_{0}\\left(t, x, v, a\\right) - 2 \\, s \\frac{\\partial^{3}}{\\partial x(\\partial a)^{2}}L_{0}\\left(t, x, v, a\\right) + 6 \\, a \\frac{\\partial^{3}}{\\partial t\\partial x\\partial v}L_{1}\\left(t, x, v, a\\right) + 4 \\, s \\frac{\\partial^{3}}{\\partial t\\partial x\\partial a}L_{1}\\left(t, x, v, a\\right) + 3 \\, a \\frac{\\partial^{2}}{(\\partial x)^{2}}L_{1}\\left(t, x, v, a\\right) + 4 \\, s \\frac{\\partial^{2}}{\\partial x\\partial v}L_{1}\\left(t, x, v, a\\right) - 2 \\, \\frac{\\partial^{3}}{\\partial t\\partial x\\partial a}L_{0}\\left(t, x, v, a\\right) + \\frac{\\partial^{2}}{\\partial x\\partial v}L_{0}\\left(t, x, v, a\\right) + 3 \\, \\frac{\\partial^{3}}{(\\partial t)^{2}\\partial x}L_{1}\\left(t, x, v, a\\right)\\right)} v - 2 \\, a \\frac{\\partial^{3}}{\\partial t\\partial v\\partial a}L_{0}\\left(t, x, v, a\\right) - 2 \\, s \\frac{\\partial^{3}}{\\partial t(\\partial a)^{2}}L_{0}\\left(t, x, v, a\\right) - a \\frac{\\partial^{2}}{\\partial x\\partial a}L_{0}\\left(t, x, v, a\\right) + a \\frac{\\partial^{2}}{(\\partial v)^{2}}L_{0}\\left(t, x, v, a\\right) + 3 \\, a \\frac{\\partial^{3}}{(\\partial t)^{2}\\partial v}L_{1}\\left(t, x, v, a\\right) + 2 \\, s \\frac{\\partial^{3}}{(\\partial t)^{2}\\partial a}L_{1}\\left(t, x, v, a\\right) + 3 \\, a \\frac{\\partial^{2}}{\\partial t\\partial x}L_{1}\\left(t, x, v, a\\right) + 4 \\, s \\frac{\\partial^{2}}{\\partial t\\partial v}L_{1}\\left(t, x, v, a\\right) - \\frac{\\partial^{3}}{(\\partial t)^{2}\\partial a}L_{0}\\left(t, x, v, a\\right) + \\frac{\\partial^{2}}{\\partial t\\partial v}L_{0}\\left(t, x, v, a\\right) - \\frac{\\partial}{\\partial x}L_{0}\\left(t, x, v, a\\right) + \\frac{\\partial^{3}}{(\\partial t)^{3}}L_{1}\\left(t, x, v, a\\right)}{v \\frac{\\partial^{2}}{\\partial x\\partial a}L_{1}\\left(t, x, v, a\\right) + a \\frac{\\partial^{2}}{\\partial v\\partial a}L_{1}\\left(t, x, v, a\\right) - \\frac{\\partial^{2}}{(\\partial a)^{2}}L_{0}\\left(t, x, v, a\\right) + \\frac{\\partial^{2}}{\\partial t\\partial a}L_{1}\\left(t, x, v, a\\right) + 2 \\, \\frac{\\partial}{\\partial v}L_{1}\\left(t, x, v, a\\right)}</script></html>", "done": true}︡
︠707d8e66-1e8e-4fb5-8eda-51ce5106af1ei︠
%md
## Second Equation of Lagrange
︡c6ee83cb-f8ba-408a-8163-a6b84cd6d899︡{"done":true,"md":"## Second Equation of Lagrange"}
︠d597d1f7-0b6b-4c7d-b0fe-2faa4b54ea13︠
(Dt(L)-(N(L)-(p*a+q*s+r*f)-(v*N(p)+a*N(q)+s*N(r)))).display()
︡c77f3e37-8c57-463a-974c-e5ad3ed7fac1︡{"html": "<html><script type=\"math/tex; mode=display\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}\\begin{array}{llcl} & M & \\longrightarrow & \\mathbb{R} \\\\ & \\left(t, x, v, a, s\\right) & \\longmapsto & v^{4} \\frac{\\partial^4\\,L}{\\partial x ^ 3\\partial s} + {\\left(3 \\, a \\frac{\\partial^4\\,L}{\\partial x ^ 2\\partial v\\partial s} + 3 \\, s \\frac{\\partial^4\\,L}{\\partial x ^ 2\\partial a\\partial s} + 3 \\, f\\left(t, x, v, a, s\\right) \\frac{\\partial^4\\,L}{\\partial x ^ 2\\partial s ^ 2} + 3 \\, \\frac{\\partial^3\\,L}{\\partial x\\partial s ^ 2} \\frac{\\partial\\,f}{\\partial x} + \\frac{\\partial^2\\,L}{\\partial s ^ 2} \\frac{\\partial^2\\,f}{\\partial x ^ 2} + 3 \\, \\frac{\\partial^4\\,L}{\\partial t\\partial x ^ 2\\partial s} - \\frac{\\partial^3\\,L}{\\partial x ^ 2\\partial a}\\right)} v^{3} + {\\left(3 \\, a^{2} \\frac{\\partial^4\\,L}{\\partial x\\partial v ^ 2\\partial s} + 6 \\, a s \\frac{\\partial^4\\,L}{\\partial x\\partial v\\partial a\\partial s} + 6 \\, a f\\left(t, x, v, a, s\\right) \\frac{\\partial^4\\,L}{\\partial x\\partial v\\partial s ^ 2} + 3 \\, s^{2} \\frac{\\partial^4\\,L}{\\partial x\\partial a ^ 2\\partial s} + 6 \\, s f\\left(t, x, v, a, s\\right) \\frac{\\partial^4\\,L}{\\partial x\\partial a\\partial s ^ 2} + 3 \\, f\\left(t, x, v, a, s\\right)^{2} \\frac{\\partial^4\\,L}{\\partial x\\partial s ^ 3} + 3 \\, a \\frac{\\partial^3\\,L}{\\partial v\\partial s ^ 2} \\frac{\\partial\\,f}{\\partial x} + 3 \\, s \\frac{\\partial^3\\,L}{\\partial a\\partial s ^ 2} \\frac{\\partial\\,f}{\\partial x} + 3 \\, f\\left(t, x, v, a, s\\right) \\frac{\\partial^3\\,L}{\\partial s ^ 3} \\frac{\\partial\\,f}{\\partial x} + 6 \\, a \\frac{\\partial^4\\,L}{\\partial t\\partial x\\partial v\\partial s} + 6 \\, s \\frac{\\partial^4\\,L}{\\partial t\\partial x\\partial a\\partial s} + 6 \\, f\\left(t, x, v, a, s\\right) \\frac{\\partial^4\\,L}{\\partial t\\partial x\\partial s ^ 2} + 3 \\, a \\frac{\\partial^3\\,L}{\\partial x ^ 2\\partial s} - 2 \\, a \\frac{\\partial^3\\,L}{\\partial x\\partial v\\partial a} + 3 \\, s \\frac{\\partial^3\\,L}{\\partial x\\partial v\\partial s} - 2 \\, s \\frac{\\partial^3\\,L}{\\partial x\\partial a ^ 2} + f\\left(t, x, v, a, s\\right) \\frac{\\partial^3\\,L}{\\partial x\\partial a\\partial s} + 3 \\, {\\left(a \\frac{\\partial\\,f}{\\partial v} + s \\frac{\\partial\\,f}{\\partial a} + f\\left(t, x, v, a, s\\right) \\frac{\\partial\\,f}{\\partial s} + \\frac{\\partial\\,f}{\\partial t}\\right)} \\frac{\\partial^3\\,L}{\\partial x\\partial s ^ 2} + {\\left(2 \\, a \\frac{\\partial^2\\,f}{\\partial x\\partial v} + 2 \\, s \\frac{\\partial^2\\,f}{\\partial x\\partial a} + 2 \\, f\\left(t, x, v, a, s\\right) \\frac{\\partial^2\\,f}{\\partial x\\partial s} + \\frac{\\partial\\,f}{\\partial x} \\frac{\\partial\\,f}{\\partial s} + 2 \\, \\frac{\\partial^2\\,f}{\\partial t\\partial x}\\right)} \\frac{\\partial^2\\,L}{\\partial s ^ 2} + 3 \\, \\frac{\\partial^3\\,L}{\\partial t\\partial s ^ 2} \\frac{\\partial\\,f}{\\partial x} + 3 \\, \\frac{\\partial^4\\,L}{\\partial t ^ 2\\partial x\\partial s} - 2 \\, \\frac{\\partial^3\\,L}{\\partial t\\partial x\\partial a} + \\frac{\\partial^2\\,L}{\\partial x\\partial v}\\right)} v^{2} + {\\left(a^{3} \\frac{\\partial^4\\,L}{\\partial v ^ 3\\partial s} + 3 \\, a^{2} s \\frac{\\partial^4\\,L}{\\partial v ^ 2\\partial a\\partial s} + 3 \\, a^{2} f\\left(t, x, v, a, s\\right) \\frac{\\partial^4\\,L}{\\partial v ^ 2\\partial s ^ 2} + 3 \\, a s^{2} \\frac{\\partial^4\\,L}{\\partial v\\partial a ^ 2\\partial s} + 6 \\, a s f\\left(t, x, v, a, s\\right) \\frac{\\partial^4\\,L}{\\partial v\\partial a\\partial s ^ 2} + 3 \\, a f\\left(t, x, v, a, s\\right)^{2} \\frac{\\partial^4\\,L}{\\partial v\\partial s ^ 3} + s^{3} \\frac{\\partial^4\\,L}{\\partial a ^ 3\\partial s} + 3 \\, s^{2} f\\left(t, x, v, a, s\\right) \\frac{\\partial^4\\,L}{\\partial a ^ 2\\partial s ^ 2} + 3 \\, s f\\left(t, x, v, a, s\\right)^{2} \\frac{\\partial^4\\,L}{\\partial a\\partial s ^ 3} + f\\left(t, x, v, a, s\\right)^{3} \\frac{\\partial^4\\,L}{\\partial s ^ 4} + 3 \\, a^{2} \\frac{\\partial^4\\,L}{\\partial t\\partial v ^ 2\\partial s} + 6 \\, a s \\frac{\\partial^4\\,L}{\\partial t\\partial v\\partial a\\partial s} + 6 \\, a f\\left(t, x, v, a, s\\right) \\frac{\\partial^4\\,L}{\\partial t\\partial v\\partial s ^ 2} + 3 \\, s^{2} \\frac{\\partial^4\\,L}{\\partial t\\partial a ^ 2\\partial s} + 6 \\, s f\\left(t, x, v, a, s\\right) \\frac{\\partial^4\\,L}{\\partial t\\partial a\\partial s ^ 2} + 3 \\, f\\left(t, x, v, a, s\\right)^{2} \\frac{\\partial^4\\,L}{\\partial t\\partial s ^ 3} + 3 \\, a^{2} \\frac{\\partial^3\\,L}{\\partial x\\partial v\\partial s} + 3 \\, a s \\frac{\\partial^3\\,L}{\\partial x\\partial a\\partial s} + 3 \\, a f\\left(t, x, v, a, s\\right) \\frac{\\partial^3\\,L}{\\partial x\\partial s ^ 2} - a^{2} \\frac{\\partial^3\\,L}{\\partial v ^ 2\\partial a} + 3 \\, a s \\frac{\\partial^3\\,L}{\\partial v ^ 2\\partial s} - 2 \\, a s \\frac{\\partial^3\\,L}{\\partial v\\partial a ^ 2} - s^{2} \\frac{\\partial^3\\,L}{\\partial a ^ 3} + s f\\left(t, x, v, a, s\\right) \\frac{\\partial^3\\,L}{\\partial a ^ 2\\partial s} + 3 \\, a \\frac{\\partial^4\\,L}{\\partial t ^ 2\\partial v\\partial s} + 3 \\, s \\frac{\\partial^4\\,L}{\\partial t ^ 2\\partial a\\partial s} + 3 \\, f\\left(t, x, v, a, s\\right) \\frac{\\partial^4\\,L}{\\partial t ^ 2\\partial s ^ 2} + 3 \\, a \\frac{\\partial^3\\,L}{\\partial t\\partial x\\partial s} - 2 \\, a \\frac{\\partial^3\\,L}{\\partial t\\partial v\\partial a} + 3 \\, s \\frac{\\partial^3\\,L}{\\partial t\\partial v\\partial s} - 2 \\, s \\frac{\\partial^3\\,L}{\\partial t\\partial a ^ 2} + f\\left(t, x, v, a, s\\right) \\frac{\\partial^3\\,L}{\\partial t\\partial a\\partial s} + 3 \\, {\\left(a \\frac{\\partial\\,f}{\\partial v} + s \\frac{\\partial\\,f}{\\partial a} + f\\left(t, x, v, a, s\\right) \\frac{\\partial\\,f}{\\partial s} + \\frac{\\partial\\,f}{\\partial t}\\right)} \\frac{\\partial^3\\,L}{\\partial t\\partial s ^ 2} - a \\frac{\\partial^2\\,L}{\\partial x\\partial a} + s \\frac{\\partial^2\\,L}{\\partial x\\partial s} + a \\frac{\\partial^2\\,L}{\\partial v ^ 2} + {\\left(3 \\, s^{2} + a f\\left(t, x, v, a, s\\right)\\right)} \\frac{\\partial^3\\,L}{\\partial v\\partial a\\partial s} + 2 \\, f\\left(t, x, v, a, s\\right) \\frac{\\partial^2\\,L}{\\partial v\\partial s} + 3 \\, {\\left(a^{2} \\frac{\\partial\\,f}{\\partial v} + a s \\frac{\\partial\\,f}{\\partial a} + a f\\left(t, x, v, a, s\\right) \\frac{\\partial\\,f}{\\partial s} + s f\\left(t, x, v, a, s\\right) + a \\frac{\\partial\\,f}{\\partial t}\\right)} \\frac{\\partial^3\\,L}{\\partial v\\partial s ^ 2} - f\\left(t, x, v, a, s\\right) \\frac{\\partial^2\\,L}{\\partial a ^ 2} + {\\left(3 \\, a s \\frac{\\partial\\,f}{\\partial v} + 3 \\, s^{2} \\frac{\\partial\\,f}{\\partial a} + 3 \\, s f\\left(t, x, v, a, s\\right) \\frac{\\partial\\,f}{\\partial s} + 2 \\, f\\left(t, x, v, a, s\\right)^{2} + 3 \\, s \\frac{\\partial\\,f}{\\partial t}\\right)} \\frac{\\partial^3\\,L}{\\partial a\\partial s ^ 2} + {\\left(a^{2} \\frac{\\partial^2\\,f}{\\partial v ^ 2} + 2 \\, a s \\frac{\\partial^2\\,f}{\\partial v\\partial a} + 2 \\, a f\\left(t, x, v, a, s\\right) \\frac{\\partial^2\\,f}{\\partial v\\partial s} + s^{2} \\frac{\\partial^2\\,f}{\\partial a ^ 2} + 2 \\, s f\\left(t, x, v, a, s\\right) \\frac{\\partial^2\\,f}{\\partial a\\partial s} + s \\frac{\\partial\\,f}{\\partial a} \\frac{\\partial\\,f}{\\partial s} + f\\left(t, x, v, a, s\\right) \\frac{\\partial\\,f}{\\partial s}^{2} + f\\left(t, x, v, a, s\\right)^{2} \\frac{\\partial^2\\,f}{\\partial s ^ 2} + 2 \\, a \\frac{\\partial^2\\,f}{\\partial t\\partial v} + 2 \\, s \\frac{\\partial^2\\,f}{\\partial t\\partial a} + 2 \\, f\\left(t, x, v, a, s\\right) \\frac{\\partial^2\\,f}{\\partial t\\partial s} + a \\frac{\\partial\\,f}{\\partial x} + {\\left(a \\frac{\\partial\\,f}{\\partial s} + s\\right)} \\frac{\\partial\\,f}{\\partial v} + f\\left(t, x, v, a, s\\right) \\frac{\\partial\\,f}{\\partial a} + \\frac{\\partial\\,f}{\\partial t} \\frac{\\partial\\,f}{\\partial s} + \\frac{\\partial^2\\,f}{\\partial t ^ 2}\\right)} \\frac{\\partial^2\\,L}{\\partial s ^ 2} + 3 \\, {\\left(a f\\left(t, x, v, a, s\\right) \\frac{\\partial\\,f}{\\partial v} + s f\\left(t, x, v, a, s\\right) \\frac{\\partial\\,f}{\\partial a} + f\\left(t, x, v, a, s\\right)^{2} \\frac{\\partial\\,f}{\\partial s} + f\\left(t, x, v, a, s\\right) \\frac{\\partial\\,f}{\\partial t}\\right)} \\frac{\\partial^3\\,L}{\\partial s ^ 3} + \\frac{\\partial^4\\,L}{\\partial t ^ 3\\partial s} - \\frac{\\partial^3\\,L}{\\partial t ^ 2\\partial a} + \\frac{\\partial^2\\,L}{\\partial t\\partial v} - \\frac{\\partial\\,L}{\\partial x}\\right)} v \\end{array}</script></html>", "done": true}︡
︠2bc12aad-1f6b-464f-9721-709a2ac2c15bi︠
%md
Multiplying by $v$
︡da5c972e-119d-42bc-a102-ef7ee58782b3︡{"done":true,"md":"Multiplying by $v$"}
︠ef66ab34-3880-40b1-a9a2-e51d82b912cb︠
v*(N(p)-Dx(L)) == (Dt(L)-(N(L)-(p*a+q*s+r*f)-(v*N(p)+a*N(q)+s*N(r))))
︡7781a766-7f45-4fe2-b5b5-7962b2a39bee︡{"html": "<html><script type=\"math/tex; mode=display\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}\\mathrm{True}</script></html>", "done": true}︡
︠3cc7d2d3-244a-4636-bd3a-9ddfb5785b0ci︠
%md
## Checking the calculations from the paper ##
︡cf7377d2-31d0-4605-850e-e59463b416ad︡{"done":true,"md":"## Checking the calculations from the paper ##"}
︠2f1d9739-7b00-41ff-b800-99709b9a7ff2︠
L = M.scalar_field(function('L')(*list(coord)))
p = M.scalar_field(function('p')(*list(coord)))
q = M.scalar_field(function('q')(*list(coord)))
r = M.scalar_field(function('r')(*list(coord)))
t=M.scalar_field(t)
x=M.scalar_field(x)
v=M.scalar_field(v)
a=M.scalar_field(a)
s=M.scalar_field(s)
︡b839c0f7-5bb1-4a13-b32b-4f8f668a3cd8︡{"done": true, "stdout": ""}︡
︠208e4985-fcaf-4e87-80d9-4e7972141031i︠
%md
Action differential Form
︡29c7050b-a8cd-418f-9a47-3e0c3734713a︡{"done":true,"md":"Action differential Form"}
︠324f0af4-b343-4ccd-ac2c-da820665390d︠
alpha = L*dt + p*(dx-v*dt) + q*(dv-a*dt) + r*(da-s*dt)
alpha.display()
︡7e34b279-8717-4f9c-9073-f5856b3be00a︡{"html": "<html><script type=\"math/tex; mode=display\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}\\left( -v p\\left(t, x, v, a, s\\right) - a q\\left(t, x, v, a, s\\right) - s r\\left(t, x, v, a, s\\right) + L\\left(t, x, v, a, s\\right) \\right) \\mathrm{d} t + p\\left(t, x, v, a, s\\right) \\mathrm{d} x + q\\left(t, x, v, a, s\\right) \\mathrm{d} v + r\\left(t, x, v, a, s\\right) \\mathrm{d} a</script></html>", "done": true}︡
︠fdb5bce0-df03-4ff9-8931-7d765cedbbaf︠
alpha == L*dt+p*dx+q*dv+r*da-(p*v+q*a+r*s)*dt
︡af881a07-cd32-48ee-89bc-2a29cbd93cc1︡{"html": "<html><script type=\"math/tex; mode=display\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}\\mathrm{True}</script></html>", "done": true}︡
︠96294154-38a3-49e7-a07b-19d43db5b78a︠
d(alpha).display()
︡1a2c0af1-700d-40d4-8050-ba609323e022︡{"html": "<html><script type=\"math/tex; mode=display\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}\\left( v \\frac{\\partial\\,p}{\\partial x} + a \\frac{\\partial\\,q}{\\partial x} + s \\frac{\\partial\\,r}{\\partial x} - \\frac{\\partial\\,L}{\\partial x} + \\frac{\\partial\\,p}{\\partial t} \\right) \\mathrm{d} t\\wedge \\mathrm{d} x + \\left( v \\frac{\\partial\\,p}{\\partial v} + a \\frac{\\partial\\,q}{\\partial v} + s \\frac{\\partial\\,r}{\\partial v} + p\\left(t, x, v, a, s\\right) - \\frac{\\partial\\,L}{\\partial v} + \\frac{\\partial\\,q}{\\partial t} \\right) \\mathrm{d} t\\wedge \\mathrm{d} v + \\left( v \\frac{\\partial\\,p}{\\partial a} + a \\frac{\\partial\\,q}{\\partial a} + s \\frac{\\partial\\,r}{\\partial a} + q\\left(t, x, v, a, s\\right) - \\frac{\\partial\\,L}{\\partial a} + \\frac{\\partial\\,r}{\\partial t} \\right) \\mathrm{d} t\\wedge \\mathrm{d} a + \\left( v \\frac{\\partial\\,p}{\\partial s} + a \\frac{\\partial\\,q}{\\partial s} + s \\frac{\\partial\\,r}{\\partial s} + r\\left(t, x, v, a, s\\right) - \\frac{\\partial\\,L}{\\partial s} \\right) \\mathrm{d} t\\wedge \\mathrm{d} s + \\left( -\\frac{\\partial\\,p}{\\partial v} + \\frac{\\partial\\,q}{\\partial x} \\right) \\mathrm{d} x\\wedge \\mathrm{d} v + \\left( -\\frac{\\partial\\,p}{\\partial a} + \\frac{\\partial\\,r}{\\partial x} \\right) \\mathrm{d} x\\wedge \\mathrm{d} a -\\frac{\\partial\\,p}{\\partial s} \\mathrm{d} x\\wedge \\mathrm{d} s + \\left( -\\frac{\\partial\\,q}{\\partial a} + \\frac{\\partial\\,r}{\\partial v} \\right) \\mathrm{d} v\\wedge \\mathrm{d} a -\\frac{\\partial\\,q}{\\partial s} \\mathrm{d} v\\wedge \\mathrm{d} s -\\frac{\\partial\\,r}{\\partial s} \\mathrm{d} a\\wedge \\mathrm{d} s</script></html>", "done": true}︡
︠a7983385-3bbf-4e84-9a30-fd36a41b74ba︠
d(alpha) == d(L).wedge(dt) + d(p).wedge(dx) + d(q).wedge(dv) + d(r).wedge(da) - d(p*v + q*a + r*s).wedge(dt)
︡cc02dc23-7dc3-4861-9c25-377da5425e1d︡{"html": "<html><script type=\"math/tex; mode=display\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}\\mathrm{True}</script></html>", "done": true}︡
︠32807d6f-bb1b-4bd1-845a-ba1cf08c9954︠
ev(alpha)(N)==L
︡cde841de-d5ea-433c-8709-f21da3fbc703︡{"html": "<html><script type=\"math/tex; mode=display\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}\\mathrm{True}</script></html>", "done": true}︡
︠7ec9f53e-a7f7-4d5c-bd8f-6c0bb5372307︠
Omega = -(p*dx+q*dv+r*da).wedge(d(t)); Omega.display()
︡4ba29cbe-0329-4313-aad6-9176eef49221︡{"html": "<html><script type=\"math/tex; mode=display\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}p\\left(t, x, v, a, s\\right) \\mathrm{d} t\\wedge \\mathrm{d} x + q\\left(t, x, v, a, s\\right) \\mathrm{d} t\\wedge \\mathrm{d} v + r\\left(t, x, v, a, s\\right) \\mathrm{d} t\\wedge \\mathrm{d} a</script></html>", "done": true}︡
︠5fdf9e15-e19b-4509-a9ba-52ec35dca2b1︠
alpha == L*dt + ev(N)(Omega)
︡9021aa30-4857-49f1-911f-0c3bc1fc6794︡{"html": "<html><script type=\"math/tex; mode=display\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}\\mathrm{True}</script></html>", "done": true}︡
︠a24e1c44-0ce3-4fbd-bf78-6d0158d32705i︠
%md
Equation of Motion ($E=0$)
︡1f20ba30-2d0c-4301-919a-91154c9fd3c6︡{"done":true,"md":"Equation of Motion ($E=0$)"}
︠148646e4-d956-469f-9315-9139da066b33︠
E = ev(N)(d(alpha))
E.display()
︡5729cf48-012d-4346-a8a5-26ec8613458f︡{"html": "<html><script type=\"math/tex; mode=display\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}\\left( -v^{2} \\frac{\\partial\\,p}{\\partial x} - a^{2} \\frac{\\partial\\,q}{\\partial v} - a s \\frac{\\partial\\,q}{\\partial a} - a f\\left(t, x, v, a, s\\right) \\frac{\\partial\\,q}{\\partial s} - a s \\frac{\\partial\\,r}{\\partial v} - s^{2} \\frac{\\partial\\,r}{\\partial a} - s f\\left(t, x, v, a, s\\right) \\frac{\\partial\\,r}{\\partial s} - {\\left(a \\frac{\\partial\\,p}{\\partial v} + s \\frac{\\partial\\,p}{\\partial a} + f\\left(t, x, v, a, s\\right) \\frac{\\partial\\,p}{\\partial s} + a \\frac{\\partial\\,q}{\\partial x} + s \\frac{\\partial\\,r}{\\partial x} - \\frac{\\partial\\,L}{\\partial x} + \\frac{\\partial\\,p}{\\partial t}\\right)} v - a p\\left(t, x, v, a, s\\right) - s q\\left(t, x, v, a, s\\right) - f\\left(t, x, v, a, s\\right) r\\left(t, x, v, a, s\\right) + a \\frac{\\partial\\,L}{\\partial v} + s \\frac{\\partial\\,L}{\\partial a} + f\\left(t, x, v, a, s\\right) \\frac{\\partial\\,L}{\\partial s} - a \\frac{\\partial\\,q}{\\partial t} - s \\frac{\\partial\\,r}{\\partial t} \\right) \\mathrm{d} t + \\left( v \\frac{\\partial\\,p}{\\partial x} + a \\frac{\\partial\\,p}{\\partial v} + s \\frac{\\partial\\,p}{\\partial a} + f\\left(t, x, v, a, s\\right) \\frac{\\partial\\,p}{\\partial s} - \\frac{\\partial\\,L}{\\partial x} + \\frac{\\partial\\,p}{\\partial t} \\right) \\mathrm{d} x + \\left( v \\frac{\\partial\\,q}{\\partial x} + a \\frac{\\partial\\,q}{\\partial v} + s \\frac{\\partial\\,q}{\\partial a} + f\\left(t, x, v, a, s\\right) \\frac{\\partial\\,q}{\\partial s} + p\\left(t, x, v, a, s\\right) - \\frac{\\partial\\,L}{\\partial v} + \\frac{\\partial\\,q}{\\partial t} \\right) \\mathrm{d} v + \\left( v \\frac{\\partial\\,r}{\\partial x} + a \\frac{\\partial\\,r}{\\partial v} + s \\frac{\\partial\\,r}{\\partial a} + f\\left(t, x, v, a, s\\right) \\frac{\\partial\\,r}{\\partial s} + q\\left(t, x, v, a, s\\right) - \\frac{\\partial\\,L}{\\partial a} + \\frac{\\partial\\,r}{\\partial t} \\right) \\mathrm{d} a + \\left( r\\left(t, x, v, a, s\\right) - \\frac{\\partial\\,L}{\\partial s} \\right) \\mathrm{d} s</script></html>", "done": true}︡
︠7c5a6845-f0cf-4f84-866d-7f2634b85352i︠
%md
Rewriting it in various ways.
︡4bd24c37-6e7d-41c1-81ab-e5e09f035b4f︡{"done":true,"md":"Rewriting it in various ways."}
︠a5bd1f3a-5ca0-40ce-b880-0e7482277df4︠
E == N(L)*dt - N(t) * d(L) + N(p)*dx - N(x)*d(p) + N(q)*dv - N(v)*d(q) + N(r)*da - N(a)*d(r) - N(p*v+q*a+r*s)*dt + N(t)*d(p*v+q*a+r*s)
︡d198836b-7f0d-46d5-a3b8-4579fd7896e6︡{"html": "<html><script type=\"math/tex; mode=display\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}\\mathrm{True}</script></html>", "done": true}︡
︠3c042410-6939-4a7d-9fdd-427a2fe0343b︠
E == N(L)*dt - d(L) + N(p)*dx - v*d(p) + N(q)*dv - a*d(q) + N(r)*da - s*d(r) - N(p*v+q*a+r*s)*dt + d(p*v+q*a+r*s)
︡36857b9c-167d-4e02-8880-33c85311ad6d︡{"html": "<html><script type=\"math/tex; mode=display\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}\\mathrm{True}</script></html>", "done": true}︡
︠ca6a4faf-b263-4178-8f04-8eb22a8152d0︠
E == N(L-p*v-q*a-r*s)*dt - d(L - p*v - q*a- r*s) - v*d(p) - a*d(q) - s*d(r) + N(p)*dx + N(q)*dv + N(r)*da
︡925da5b9-2723-41a2-a75b-b9c4ec622dea︡{"html": "<html><script type=\"math/tex; mode=display\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}\\mathrm{True}</script></html>", "done": true}︡
︠86a5dfee-6411-49a9-a7de-baa0b70fe674︠
d(p*v) == v*d(p) + p*d(v)
︡3992e251-d34f-4a70-b315-03daf1515202︡{"html": "<html><script type=\"math/tex; mode=display\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}\\mathrm{True}</script></html>", "done": true}︡
︠ff2d935a-4859-4e83-a475-dbb847e0f266︠
d(q*a) == a*d(q) + q*d(a)
︡2ea485e6-90aa-4ec3-887a-6a6ecd7a1d04︡{"html": "<html><script type=\"math/tex; mode=display\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}\\mathrm{True}</script></html>", "done": true}︡
︠31ab7ba9-349f-411c-a72b-d0eebd61bae9︠
d(r*s) == s*d(r) + r*d(s)
︡d8902f31-d0ce-42e9-b290-4d5f59a14556︡{"html": "<html><script type=\"math/tex; mode=display\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}\\mathrm{True}</script></html>", "done": true}︡
︠f1361290-3f68-4ce9-8c48-e2befd8ccac9︠
E == N(L - p*v - q*a - r*s)*dt - d(L) + p*dv + q*da + r*ds + N(p)*dx + N(q)*dv + N(r)*da
︡4ba3008c-7e1a-4907-81f8-a9bbe96a44a5︡{"html": "<html><script type=\"math/tex; mode=display\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}\\mathrm{True}</script></html>", "done": true}︡
︠8891fe59-6741-4b95-b091-7ea8b69f29b1︠
N(p*v) == p*N(v) + v*N(p)
︡6114cd1f-dabc-484a-9687-035a9ff090d2︡{"html": "<html><script type=\"math/tex; mode=display\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}\\mathrm{True}</script></html>", "done": true}︡
︠6145e817-d4fc-496d-8c2b-254c0a41e1f8︠
E == N(L)*dt - (p*a+q*s+r*f)*dt -(v*N(p) + a*N(q) + s*N(r) )*dt - d(L) + p*dv + q*da + r*ds + N(p)*dx + N(q)*dv + N(r)*da
︡2c8a7880-5a6f-4986-a5cb-5710c6c055f4︡{"html": "<html><script type=\"math/tex; mode=display\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}\\mathrm{True}</script></html>", "done": true}︡
︠a7b42edc-b30a-4c30-ac7f-c19a3250057c︠
E == ( N(L) - (p*a + q*s + r*f) - (v*N(p) + a*N(q) + s*N(r)))*dt + N(p)*dx + (N(q)+p)*dv + (N(r)+q)*da + r*ds - d(L)
︡6417120e-9eaf-435c-9df4-87818243bcf1︡{"html": "<html><script type=\"math/tex; mode=display\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}\\mathrm{True}</script></html>", "done": true}︡
︠1e6896d5-fe77-4108-b55b-d8b3d555fcc6︠
d(L) == Dt(L)*dt + Dx(L)*dx + Dv(L)*dv + Da(L)*da + Ds(L)*ds
︡163d7ab1-5cb7-450e-b8a3-85119fbbe568︡{"html": "<html><script type=\"math/tex; mode=display\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}\\mathrm{True}</script></html>", "done": true}︡
︠3cfe5c30-e547-4b43-931f-3379fd943ec2︠
r=Ds(L); r.display()
︡885de680-aa0e-421c-b6c9-7644f579f4d0︡{"html": "<html><script type=\"math/tex; mode=display\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}\\begin{array}{llcl} & M & \\longrightarrow & \\mathbb{R} \\\\ & \\left(t, x, v, a, s\\right) & \\longmapsto & \\frac{\\partial\\,L}{\\partial s} \\end{array}</script></html>", "done": true}︡
︠e9d3ecb2-b786-4f9c-a980-400a82a1db62︠
q=Da(L)-N(r); q.display()
︡81ca3e57-0ed3-4db6-880a-cbae49fa270a︡{"html": "<html><script type=\"math/tex; mode=display\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}\\begin{array}{llcl} & M & \\longrightarrow & \\mathbb{R} \\\\ & \\left(t, x, v, a, s\\right) & \\longmapsto & -v \\frac{\\partial^2\\,L}{\\partial x\\partial s} - a \\frac{\\partial^2\\,L}{\\partial v\\partial s} - s \\frac{\\partial^2\\,L}{\\partial a\\partial s} - f\\left(t, x, v, a, s\\right) \\frac{\\partial^2\\,L}{\\partial s ^ 2} - \\frac{\\partial^2\\,L}{\\partial t\\partial s} + \\frac{\\partial\\,L}{\\partial a} \\end{array}</script></html>", "done": true}︡
︠ddabe770-b860-45f6-99ac-d18561632ea9︠
p=Dv(L)-N(q); p.display()
︡a2e77f58-bb51-4908-a139-58e2123494ba︡{"html": "<html><script type=\"math/tex; mode=display\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}\\begin{array}{llcl} & M & \\longrightarrow & \\mathbb{R} \\\\ & \\left(t, x, v, a, s\\right) & \\longmapsto & v^{2} \\frac{\\partial^3\\,L}{\\partial x ^ 2\\partial s} + a^{2} \\frac{\\partial^3\\,L}{\\partial v ^ 2\\partial s} + 2 \\, a s \\frac{\\partial^3\\,L}{\\partial v\\partial a\\partial s} + 2 \\, a f\\left(t, x, v, a, s\\right) \\frac{\\partial^3\\,L}{\\partial v\\partial s ^ 2} + s^{2} \\frac{\\partial^3\\,L}{\\partial a ^ 2\\partial s} + 2 \\, s f\\left(t, x, v, a, s\\right) \\frac{\\partial^3\\,L}{\\partial a\\partial s ^ 2} + f\\left(t, x, v, a, s\\right)^{2} \\frac{\\partial^3\\,L}{\\partial s ^ 3} + {\\left(2 \\, a \\frac{\\partial^3\\,L}{\\partial x\\partial v\\partial s} + 2 \\, s \\frac{\\partial^3\\,L}{\\partial x\\partial a\\partial s} + 2 \\, f\\left(t, x, v, a, s\\right) \\frac{\\partial^3\\,L}{\\partial x\\partial s ^ 2} + \\frac{\\partial^2\\,L}{\\partial s ^ 2} \\frac{\\partial\\,f}{\\partial x} + 2 \\, \\frac{\\partial^3\\,L}{\\partial t\\partial x\\partial s} - \\frac{\\partial^2\\,L}{\\partial x\\partial a}\\right)} v + 2 \\, a \\frac{\\partial^3\\,L}{\\partial t\\partial v\\partial s} + 2 \\, s \\frac{\\partial^3\\,L}{\\partial t\\partial a\\partial s} + 2 \\, f\\left(t, x, v, a, s\\right) \\frac{\\partial^3\\,L}{\\partial t\\partial s ^ 2} + a \\frac{\\partial^2\\,L}{\\partial x\\partial s} - a \\frac{\\partial^2\\,L}{\\partial v\\partial a} + s \\frac{\\partial^2\\,L}{\\partial v\\partial s} - s \\frac{\\partial^2\\,L}{\\partial a ^ 2} + {\\left(a \\frac{\\partial\\,f}{\\partial v} + s \\frac{\\partial\\,f}{\\partial a} + f\\left(t, x, v, a, s\\right) \\frac{\\partial\\,f}{\\partial s} + \\frac{\\partial\\,f}{\\partial t}\\right)} \\frac{\\partial^2\\,L}{\\partial s ^ 2} + \\frac{\\partial^3\\,L}{\\partial t ^ 2\\partial s} - \\frac{\\partial^2\\,L}{\\partial t\\partial a} + \\frac{\\partial\\,L}{\\partial v} \\end{array}</script></html>", "done": true}︡
︠d8c4c8de-f0f2-4c51-b41d-9c28f5f1ee11i︠
%md
## For example: The Schiff and Poirier Lagrangian ##
︡39146a47-5e37-4a92-866f-ba66ca0b6206︡{"done":true,"md":"## For example: The Schiff and Poirier Lagrangian ##"}
︠26063432-8bf2-4387-a355-1b11ee3d7a0e︠
hbar = var('hbar',latex_name='\hbar')
m = var('m')
V = M.scalar_field(function('V')(var('x')))
Lp = 1/2*m*v^2  - V - hbar^2/4/m*(s/v^3-5/2*a^2/v^4); Lp.display()
︡00a52cb9-034a-4fd9-a095-a397e0cf5c6b︡{"html": "<html><script type=\"math/tex; mode=display\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}\\begin{array}{llcl} & M & \\longrightarrow & \\mathbb{R} \\\\ & \\left(t, x, v, a, s\\right) & \\longmapsto & \\frac{4 \\, m^{2} v^{6} - 8 \\, m v^{4} V\\left(x\\right) + 5 \\, a^{2} {\\hbar}^{2} - 2 \\, {\\hbar}^{2} s v}{8 \\, m v^{4}} \\end{array}</script></html>", "done": true}︡
︠2423d56a-fa93-4edd-a5f0-cc81ec135410︠
Lp1 = Ds(Lp); Lp1.display()
︡0953f32e-b3f0-489f-8955-b80807b39326︡{"html": "<html><script type=\"math/tex; mode=display\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}\\begin{array}{llcl} & M & \\longrightarrow & \\mathbb{R} \\\\ & \\left(t, x, v, a, s\\right) & \\longmapsto & -\\frac{{\\hbar}^{2}}{4 \\, m v^{3}} \\end{array}</script></html>", "done": true}︡
︠9c354f8f-b461-4ba3-b6d1-4b291b68bc56︠
Lp0 = Lp - s * Lp1; Lp0.display()
︡8aae1adf-8265-4edc-9abe-b1f266489b7b︡{"html": "<html><script type=\"math/tex; mode=display\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}\\begin{array}{llcl} & M & \\longrightarrow & \\mathbb{R} \\\\ & \\left(t, x, v, a, s\\right) & \\longmapsto & \\frac{4 \\, m^{2} v^{6} - 8 \\, m v^{4} V\\left(x\\right) + 5 \\, a^{2} {\\hbar}^{2}}{8 \\, m v^{4}} \\end{array}</script></html>", "done": true}︡
︠16c9e99b-3fed-487e-9717-34935550796a︠
Lp == Lp0 + s*Lp1
︡b77c3dd5-de06-45eb-be14-b4626e2b41d0︡{"html": "<html><script type=\"math/tex; mode=display\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}\\mathrm{True}</script></html>", "done": true}︡
︠f37d66b4-20c2-41f4-ba1e-58561f21e4fe︠
eq1p = eq1.expr().substitute_function(L.expr().operator(),Lp.expr().function(*list(coord))); eq1p
︡7ecddb8f-da46-4e6d-b368-446b8150c374︡{"html": "<html><script type=\"math/tex; mode=display\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}\\frac{1}{2} \\, a {\\left(\\frac{6 \\, {\\left(5 \\, m^{2} v^{4} - 4 \\, m v^{2} V\\left(x\\right)\\right)}}{m v^{4}} - \\frac{4 \\, {\\left(12 \\, m^{2} v^{5} - 16 \\, m v^{3} V\\left(x\\right) - {\\hbar}^{2} s\\right)}}{m v^{5}} + \\frac{5 \\, {\\left(4 \\, m^{2} v^{6} - 8 \\, m v^{4} V\\left(x\\right) + 5 \\, a^{2} {\\hbar}^{2} - 2 \\, {\\hbar}^{2} s v\\right)}}{m v^{6}}\\right)} - \\frac{10 \\, a^{3} {\\hbar}^{2}}{m v^{6}} + \\frac{a {\\hbar}^{2} s}{m v^{5}} + \\frac{{\\hbar}^{2} f\\left(t, x, v, a, s\\right)}{4 \\, m v^{4}} + \\frac{\\partial}{\\partial x}V\\left(x\\right)</script></html>", "done": true}︡
︠0ef9ebd9-d0cc-4718-872d-d08e1614c26f︠
solve(eq1p,f.expr())
︡d725b641-2f7c-48bb-be34-3447548d7ccc︡{"html": "<html><script type=\"math/tex; mode=display\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}\\left[f\\left(t, x, v, a, s\\right) = -\\frac{2 \\, {\\left(2 \\, a m^{2} v^{6} + 2 \\, m v^{6} \\frac{\\partial}{\\partial x}V\\left(x\\right) + 5 \\, a^{3} {\\hbar}^{2} - 4 \\, a {\\hbar}^{2} s v\\right)}}{{\\hbar}^{2} v^{2}}\\right]</script></html>", "done": true}︡
︠8604ea3c-bfd4-4be6-a222-854d322f958c︠

︡a59c7786-1494-407a-876a-cfa376ece267︡









